# Load ResInsight Processing Server Client Library
import rips

# Connect to ResInsight instance
resInsight = rips.Instance.find()

well_paths = resInsight.project.import_well_paths(
    well_path_folder="D:/Projects/ResInsight-regression-test/ModelData/norne/wellpaths"
)
if resInsight.project.has_warnings():
    for warning in resInsight.project.warnings():
        print(warning)


for well_path in well_paths:
    print("Imported from folder: " + well_path.name)

well_paths = resInsight.project.import_well_paths(
    well_path_files=[
        "D:/Projects/ResInsight-regression-test/ModelData/Norne_WellPaths/E-3H.json",
        "D:/Projects/ResInsight-regression-test/ModelData/Norne_WellPaths/C-1H.json",
    ]
)
if resInsight.project.has_warnings():
    for warning in resInsight.project.warnings():
        print(warning)


for well_path in well_paths:
    print("Imported from individual files: " + well_path.name)


well_path_names = resInsight.project.import_well_log_files(
    well_log_folder="D:/Projects/ResInsight-regression-test/ModelData/Norne_PLT_LAS"
)
if resInsight.project.has_warnings():
    for warning in resInsight.project.warnings():
        print(warning)

for well_path_name in well_path_names:
    print("Imported well log file for: " + well_path_name)



"""
ResInsight 3d view module
"""

import builtins
import Commands_pb2 as Cmd

import rips.case  # Circular import of Case, which already imports View. Use full name.
from .pdmobject import add_method
from .resinsight_classes import View, ViewWindow, EclipseView, GeoMechView


@add_method(View)
def apply_cell_result(self, result_type, result_variable):
    """Apply a regular cell result

    Arguments:
        result_type (str): String representing the result category. The valid values are::
            - DYNAMIC_NATIVE
            - STATIC_NATIVE
            - SOURSIMRL
            - GENERATED
            - INPUT_PROPERTY
            - FORMATION_NAMES
            - FLOW_DIAGNOSTICS
            - INJECTION_FLOODING
        result_variable (str): String representing the result variable.
    """
    cell_result = self.cell_result()
    cell_result.result_type = result_type
    cell_result.result_variable = result_variable
    cell_result.update()


@add_method(View)
def apply_flow_diagnostics_cell_result(
    self,
    result_variable="TOF",
    selection_mode="FLOW_TR_BY_SELECTION",
    injectors=None,
    producers=None,
):
    """Apply a flow diagnostics cell result

    **Parameters**::

        Parameter           | Description                                            | Type
        ------------------- | ------------------------------------------------------ | -----
        result_variable     | String representing the result value                   | String
        selection_mode      | String specifying which tracers to select              | String
        injectors           | List of injector names, used by 'FLOW_TR_BY_SELECTION' | String List
        producers           | List of injector names, used by 'FLOW_TR_BY_SELECTION' | String List

    **Enum compdat_export**::

        Option                  | Description
        ------------------------| ------------
        "TOF"                   | Time of flight
        "Fraction"              | Fraction
        "MaxFractionTracer"     | Max Fraction Tracer
        "Communication"         | Communication

    """
    if injectors is None:
        injectors = []
    if producers is None:
        producers = []
    cell_result = self.cell_result()
    cell_result.result_type = "FLOW_DIAGNOSTICS"
    cell_result.result_variable = result_variable
    cell_result.flow_tracer_selection_mode = selection_mode
    if selection_mode == "FLOW_TR_BY_SELECTION":
        cell_result.selected_injector_tracers = injectors
        cell_result.selected_producer_tracers = producers
    cell_result.update()


@add_method(View)
def clone(self):
    """Clone the current view"""
    view_id = self._execute_command(
        cloneView=Cmd.CloneViewRequest(viewId=self.id)
    ).createViewResult.viewId
    return self.case().view(view_id)


@add_method(View)
def set_time_step(self, time_step):
    """Set the time step for current view"""
    case_id = self.case().id
    return self._execute_command(
        setTimeStep=Cmd.SetTimeStepParams(
            caseId=case_id, viewId=self.id, timeStep=time_step
        )
    )


@add_method(View)
def export_sim_well_fracture_completions(
    self, time_step, simulation_well_names, file_split, compdat_export
):
    """Export fracture completions for simulation wells

    **Parameters**::

        Parameter                   | Description                                      | Type
        ----------------------------| ------------------------------------------------ | -----
        time_step                   | Time step to export for                          | Integer
        simulation_well_names       | List of simulation well names                    | List
        file_split                  | Controls how export data is split into files     | String enum
        compdat_export              | Compdat export type                              | String enum

    **Enum file_split**::

        Option                              | Description
        ----------------------------------- | ------------
        "UNIFIED_FILE" <b>Default Option</b>| A single file with all transmissibilities
        "SPLIT_ON_WELL"                     | One file for each well transmissibilities
        "SPLIT_ON_WELL_AND_COMPLETION_TYPE" | One file for each completion type for each well

    **Enum compdat_export**::

        Option                                   | Description
        -----------------------------------------| ------------
        "TRANSMISSIBILITIES"<b>Default Option</b>| Direct export of transmissibilities
        "WPIMULT_AND_DEFAULT_CONNECTION_FACTORS" | Include export of WPIMULT

    """
    if isinstance(simulation_well_names, str):
        simulation_well_names = [simulation_well_names]

    case_id = self.case().id
    return self._execute_command(
        exportSimWellFractureCompletions=Cmd.ExportSimWellPathFracRequest(
            caseId=case_id,
            viewId=self.id,
            timeStep=time_step,
            simulationWellNames=simulation_well_names,
            fileSplit=file_split,
            compdatExport=compdat_export,
        )
    )


@add_method(View)
def export_visible_cells(
    self,
    export_keyword="FLUXNUM",
    visible_active_cells_value=1,
    hidden_active_cells_value=0,
    inactive_cells_value=0,
):
    """Export special properties for all visible cells.

    Arguments:
        export_keyword (string): The keyword to export.
        Choices: 'FLUXNUM' or 'MULTNUM'. Default: 'FLUXNUM'
        visible_active_cells_value (int): Value to export forvisible active cells. Default: 1
        hidden_active_cells_value (int): Value to export for hidden active cells. Default: 0
        inactive_cells_value (int): Value to export for inactive cells. Default: 0
    """
    case_id = self.case().id
    return self._execute_command(
        exportVisibleCells=Cmd.ExportVisibleCellsRequest(
            caseId=case_id,
            viewId=self.id,
            exportKeyword=export_keyword,
            visibleActiveCellsValue=visible_active_cells_value,
            hiddenActiveCellsValue=hidden_active_cells_value,
            inactiveCellsValue=inactive_cells_value,
        )
    )


@add_method(View)
def export_property(self, undefined_value=0.0):
    """Export the current Eclipse property from the view

    Arguments:
        undefined_value (double): Value to use for undefined values. Defaults to 0.0
    """
    case_id = self.case().id
    return self._execute_command(
        exportPropertyInViews=Cmd.ExportPropertyInViewsRequest(
            caseId=case_id, viewIds=[self.id], undefinedValue=undefined_value
        )
    )


@add_method(ViewWindow)
def case(self):
    """Get the case the view belongs to"""
    mycase = self.ancestor(rips.case.Case)
    assert mycase is not None
    return mycase


@add_method(ViewWindow)
def export_snapshot(self, prefix="", export_folder=""):
    """Export snapshot for the current view

    Arguments:
        prefix (str): Exported file name prefix
        export_folder(str): The path to export to. By default will use the global export folder
    """
    case_id = self.case().id
    return self._execute_command(
        exportSnapshots=Cmd.ExportSnapshotsRequest(
            type="VIEWS",
            prefix=prefix,
            caseId=case_id,
            viewId=self.id,
            exportFolder=export_folder,
        )
    )



# pylint: disable=too-many-arguments
# pylint: disable=no-member
"""
The ResInsight project module
"""
import builtins
import grpc

from .case import Case
from .gridcasegroup import GridCaseGroup
from .pdmobject import PdmObjectBase, add_method, add_static_method
from .plot import Plot
from .view import View

import Commands_pb2
from Definitions_pb2 import Empty
import Project_pb2_grpc
import Project_pb2
import PdmObject_pb2
from .resinsight_classes import Project, PlotWindow, WellPath, SummaryCase


@add_method(Project)
def __custom_init__(self, pb2_object, channel):
    self._project_stub = Project_pb2_grpc.ProjectStub(self._channel)


@add_static_method(Project)
def create(channel):
    project_stub = Project_pb2_grpc.ProjectStub(channel)
    pb2_object = project_stub.GetPdmObject(Empty())
    return Project(pb2_object, channel)


@add_method(Project)
def open(self, path):
    """Open a new project from the given path

    Arguments:
        path(str): path to project file

    """
    self._execute_command(openProject=Commands_pb2.FilePathRequest(path=path))
    return self


@add_method(Project)
def save(self, path=""):
    """Save the project to the existing project file, or to a new file

    Arguments:
        path(str): File path to the file to save the project to. If empty, saves to the active project file
    """
    self._execute_command(saveProject=Commands_pb2.SaveProjectRequest(filePath=path))
    return self


@add_method(Project)
def close(self):
    """Close the current project (and open new blank project)"""
    self._execute_command(closeProject=Empty())


@add_method(Project)
def load_case(self, path, grid_only=False):
    """Load a new grid case from the given file path

    Arguments:
        path(str): file path to case
    Returns:
        :class:`rips.generated.generated_classes.Case`
    """
    command_reply = self._execute_command(
        loadCase=Commands_pb2.FilePathRequest(path=path, gridOnly=grid_only)
    )
    return self.case(command_reply.loadCaseResult.id)


@add_method(Project)
def selected_cases(self):
    """Get a list of all grid cases selected in the project tree

    Returns:
        A list of :class:`rips.generated.generated_classes.Case`
    """
    case_infos = self._project_stub.GetSelectedCases(Empty())
    cases = []
    for case_info in case_infos.data:
        cases.append(self.case(case_info.id))
    return cases


@add_method(Project)
def cases(self):
    """Get a list of all grid cases in the project

    Returns:
        A list of :class:`rips.generated.generated_classes.Case`
    """
    return self.descendants(Case)


@add_method(Project)
def case(self, case_id):
    """Get a specific grid case from the provided case Id

    Arguments:
        id(int): case id
    Returns:
        :class:`rips.generated.resinsight_classes.Case`
    """
    allCases = self.cases()
    for case in allCases:
        if case.id == case_id:
            return case
    return None


@add_method(Project)
def replace_source_cases(self, grid_list_file, case_group_id=0):
    """Replace all source grid cases within a case group

    Arguments:
        grid_list_file (str): path to file containing a list of cases
        case_group_id (int): id of the case group to replace
    """
    return self._execute_command(
        replaceSourceCases=Commands_pb2.ReplaceSourceCasesRequest(
            gridListFile=grid_list_file, caseGroupId=case_group_id
        )
    )


@add_method(Project)
def create_grid_case_group(self, case_paths):
    """Create a Grid Case Group from a list of cases

    Arguments:
        case_paths (list): list of file path strings
    Returns:
        :class:`rips.generated.resinsight_classes.GridCaseGroup`
    """
    command_reply = self._execute_command(
        createGridCaseGroup=Commands_pb2.CreateGridCaseGroupRequest(
            casePaths=case_paths
        )
    )
    return self.grid_case_group(command_reply.createGridCaseGroupResult.groupId)


@add_method(Project)
def summary_cases(self):
    """Get a list of all summary cases in the Project

    Returns: A list of :class:`rips.generated.resinsight_classes.SummaryCase`
    """
    return self.descendants(SummaryCase)


@add_method(Project)
def views(self):
    """Get a list of views belonging to a project"""
    return self.descendants(View)


@add_method(Project)
def view(self, view_id):
    """Get a particular view belonging to a case by providing view id

    Arguments:
        view_id(int): view id
    Returns:
        :class:`rips.generated.generated_classes.View`
    """
    views = self.views()
    for view_object in views:
        if view_object.id == view_id:
            return view_object
    return None


@add_method(Project)
def plots(self):
    """Get a list of all plots belonging to a project

    Returns:
        List of :class:`rips.generated.generated_classes.Plot`
    """
    resinsight_classes = self.descendants(PlotWindow)
    plot_list = []
    for pdm_object in resinsight_classes:
        if pdm_object.id != -1:
            plot_list.append(pdm_object)
    return plot_list


@add_method(Project)
def plot(self, view_id):
    """Get a particular plot by providing view id

    Arguments:
        view_id(int): view id

    Returns:
        :class:`rips.generated.generated_classes.Plot`
    """
    plots = self.plots()
    for plot_object in plots:
        if plot_object.id == view_id:
            return plot_object
    return None


@add_method(Project)
def grid_case_groups(self):
    """Get a list of all grid case groups in the project

    Returns:
        List of :class:`rips.generated.generated_classes.GridCaseGroup`

    """
    case_groups = self.descendants(GridCaseGroup)
    return case_groups


@add_method(Project)
def grid_case_group(self, group_id):
    """Get a particular grid case group belonging to a project

    Arguments:
        groupId(int): group id

    Returns:
        :class:`rips.generated.generated_classes.GridCaseGroup`
    """
    case_groups = self.grid_case_groups()
    for case_group in case_groups:
        if case_group.group_id == group_id:
            return case_group
    return None


@add_method(Project)
def export_multi_case_snapshots(self, grid_list_file):
    """Export snapshots for a set of cases

    Arguments:
        grid_list_file (str): Path to a file containing a list of grids to export snapshot for
    """
    return self._execute_command(
        exportMultiCaseSnapshot=Commands_pb2.ExportMultiCaseRequest(
            gridListFile=grid_list_file
        )
    )


@add_method(Project)
def export_snapshots(self, snapshot_type="ALL", prefix="", plot_format="PNG"):
    """Export all snapshots of a given type

    Arguments:
        snapshot_type (str): Enum string ('ALL', 'VIEWS' or 'PLOTS')
        prefix (str): Exported file name prefix
        plot_format(str): Enum string, 'PNG' or 'PDF'
    """
    return self._execute_command(
        exportSnapshots=Commands_pb2.ExportSnapshotsRequest(
            type=snapshot_type,
            prefix=prefix,
            caseId=-1,
            viewId=-1,
            plotOutputFormat=plot_format,
        )
    )


@add_method(Project)
def export_well_paths(self, well_paths=None, md_step_size=5.0):
    """Export a set of well paths

    Arguments:
        well_paths(list): List of strings of well paths. If none, export all.
        md_step_size(double): resolution of the exported well path
    """
    if well_paths is None:
        well_paths = []
    elif isinstance(well_paths, str):
        well_paths = [well_paths]
    return self._execute_command(
        exportWellPaths=Commands_pb2.ExportWellPathRequest(
            wellPathNames=well_paths, mdStepSize=md_step_size
        )
    )


@add_method(Project)
def scale_fracture_template(
    self, template_id, half_length, height, d_factor, conductivity
):
    """Scale fracture template parameters

    Arguments:
        template_id(int): ID of fracture template
        half_length (double): Half Length scale factor
        height (double): Height scale factor
        d_factor (double): D-factor scale factor
        conductivity (double): Conductivity scale factor
    """
    return self._execute_command(
        scaleFractureTemplate=Commands_pb2.ScaleFractureTemplateRequest(
            id=template_id,
            halfLength=half_length,
            height=height,
            dFactor=d_factor,
            conductivity=conductivity,
        )
    )


@add_method(Project)
def set_fracture_containment(self, template_id, top_layer, base_layer):
    """Set fracture template containment parameters

    Arguments:
        template_id(int): ID of fracture template
        top_layer (int): Top layer containment
        base_layer (int): Base layer containment
    """
    return self._execute_command(
        setFractureContainment=Commands_pb2.SetFracContainmentRequest(
            id=template_id, topLayer=top_layer, baseLayer=base_layer
        )
    )


@add_method(Project)
def import_well_paths(self, well_path_files=None, well_path_folder=""):
    """Import well paths into project

    Arguments:
        well_path_files(list): List of file paths to import
        well_path_folder(str): A folder path containing files to import

    Returns:
        List of :class:`rips.generated.generated_classes.WellPath`
    """
    if well_path_files is None:
        well_path_files = []

    res = self._execute_command(
        importWellPaths=Commands_pb2.ImportWellPathsRequest(
            wellPathFolder=well_path_folder, wellPathFiles=well_path_files
        )
    )
    well_paths = []
    for well_path_name in res.importWellPathsResult.wellPathNames:
        well_paths.append(self.well_path_by_name(well_path_name))
    return well_paths


@add_method(Project)
def well_paths(self):
    """Get a list of all well paths in the project

    Returns:
        List of :class:`rips.generated.generated_classes.WellPath`
    """
    return self.descendants(WellPath)


@add_method(Project)
def well_path_by_name(self, well_path_name):
    """Get a specific well path by name from the project

    Returns:
        :class:`rips.generated.generated_classes.WellPath`
    """
    all_well_paths = self.well_paths()
    for well_path in all_well_paths:
        if well_path.name == well_path_name:
            return well_path
    return None


@add_method(Project)
def import_well_log_files(self, well_log_files=None, well_log_folder=""):
    """Import well log files into project

    Arguments:
        well_log_files(list): List of file paths to import
        well_log_folder(str): A folder path containing files to import

    Returns:
        A list of well path names (strings) that had logs imported
    """

    if well_log_files is None:
        well_log_files = []
    res = self._execute_command(
        importWellLogFiles=Commands_pb2.ImportWellLogFilesRequest(
            wellLogFolder=well_log_folder, wellLogFiles=well_log_files
        )
    )
    return res.importWellLogFilesResult.wellPathNames


@add_method(Project)
def import_formation_names(self, formation_files=None):
    """Import formation names into project

    Arguments:
        formation_files(list): list of files to import

    """
    if formation_files is None:
        formation_files = []
    elif isinstance(formation_files, str):
        formation_files = [formation_files]

    self._execute_command(
        importFormationNames=Commands_pb2.ImportFormationNamesRequest(
            formationFiles=formation_files, applyToCaseId=-1
        )
    )



######################################################################
# This script retrieves cell result data and alters it
######################################################################
import rips

resinsight = rips.Instance.find()

view = resinsight.project.views()[0]
results = view.cell_result_data()
print("Number of result values: ", len(results))

newresults = []
for i in range(0, len(results)):
    newresults.append(results[i] * -1.0)
view.set_cell_result_data(newresults)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Project.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2
import Case_pb2 as Case__pb2
import PdmObject_pb2 as PdmObject__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rProject.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\x1a\nCase.proto\x1a\x0fPdmObject.proto2\xc8\x02\n\x07Project\x12\x32\n\x0eGetCurrentCase\x12\x0b.rips.Empty\x1a\x11.rips.CaseRequest\"\x00\x12\x36\n\x10GetSelectedCases\x12\x0b.rips.Empty\x1a\x13.rips.CaseInfoArray\"\x00\x12\x33\n\x10GetAllCaseGroups\x12\x0b.rips.Empty\x1a\x10.rips.CaseGroups\"\x00\x12\x31\n\x0bGetAllCases\x12\x0b.rips.Empty\x1a\x13.rips.CaseInfoArray\"\x00\x12\x39\n\x0fGetCasesInGroup\x12\x0f.rips.CaseGroup\x1a\x13.rips.CaseInfoArray\"\x00\x12.\n\x0cGetPdmObject\x12\x0b.rips.Empty\x1a\x0f.rips.PdmObject\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Project_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PROJECT']._serialized_start=72
  _globals['_PROJECT']._serialized_end=400
# @@protoc_insertion_point(module_scope)



# Load ResInsight Processing Server Client Library
import rips
import tempfile
import pathlib

# Connect to ResInsight instance
resInsight = rips.Instance.find()

# Data will be written to temp
tmpdir = pathlib.Path(tempfile.gettempdir())

# Find all eclipse contour maps of the project
contour_maps = resInsight.project.descendants(rips.EclipseContourMap)
print("Number of eclipse contour maps:", len(contour_maps))

# Export the contour maps to a text file
for index, contour_map in enumerate(contour_maps):
    filename = "eclipse_contour_map" + str(index) + ".txt"
    filepath = tmpdir / filename
    print("Exporting to:", filepath)
    contour_map.export_to_text(str(filepath))

# The contour maps is also available for a Case
cases = resInsight.project.cases()
for case in cases:
    contour_maps = case.descendants(rips.GeoMechContourMap)
    # Export the contour maps to a text file
    for index, contour_map in enumerate(contour_maps):
        filename = "geomech_contour_map" + str(index) + ".txt"
        filepath = tmpdir / filename
        print("Exporting to:", filepath)
        contour_map.export_to_text(str(filepath))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import Definitions_pb2 as Definitions__pb2
import PdmObject_pb2 as PdmObject__pb2


class PdmObjectServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDescendantPdmObjects = channel.unary_unary(
                '/rips.PdmObjectService/GetDescendantPdmObjects',
                request_serializer=PdmObject__pb2.PdmDescendantObjectRequest.SerializeToString,
                response_deserializer=PdmObject__pb2.PdmObjectArray.FromString,
                )
        self.GetChildPdmObjects = channel.unary_unary(
                '/rips.PdmObjectService/GetChildPdmObjects',
                request_serializer=PdmObject__pb2.PdmChildObjectRequest.SerializeToString,
                response_deserializer=PdmObject__pb2.PdmObjectArray.FromString,
                )
        self.GetAncestorPdmObject = channel.unary_unary(
                '/rips.PdmObjectService/GetAncestorPdmObject',
                request_serializer=PdmObject__pb2.PdmParentObjectRequest.SerializeToString,
                response_deserializer=PdmObject__pb2.PdmObject.FromString,
                )
        self.CreateChildPdmObject = channel.unary_unary(
                '/rips.PdmObjectService/CreateChildPdmObject',
                request_serializer=PdmObject__pb2.CreatePdmChildObjectRequest.SerializeToString,
                response_deserializer=PdmObject__pb2.PdmObject.FromString,
                )
        self.UpdateExistingPdmObject = channel.unary_unary(
                '/rips.PdmObjectService/UpdateExistingPdmObject',
                request_serializer=PdmObject__pb2.PdmObject.SerializeToString,
                response_deserializer=Definitions__pb2.Empty.FromString,
                )
        self.CallPdmObjectGetter = channel.unary_stream(
                '/rips.PdmObjectService/CallPdmObjectGetter',
                request_serializer=PdmObject__pb2.PdmObjectGetterRequest.SerializeToString,
                response_deserializer=PdmObject__pb2.PdmObjectGetterReply.FromString,
                )
        self.CallPdmObjectSetter = channel.stream_unary(
                '/rips.PdmObjectService/CallPdmObjectSetter',
                request_serializer=PdmObject__pb2.PdmObjectSetterChunk.SerializeToString,
                response_deserializer=Definitions__pb2.ClientToServerStreamReply.FromString,
                )
        self.CallPdmObjectMethod = channel.unary_unary(
                '/rips.PdmObjectService/CallPdmObjectMethod',
                request_serializer=PdmObject__pb2.PdmObjectMethodRequest.SerializeToString,
                response_deserializer=PdmObject__pb2.PdmObject.FromString,
                )


class PdmObjectServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDescendantPdmObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChildPdmObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAncestorPdmObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateChildPdmObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateExistingPdmObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallPdmObjectGetter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallPdmObjectSetter(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallPdmObjectMethod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PdmObjectServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDescendantPdmObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDescendantPdmObjects,
                    request_deserializer=PdmObject__pb2.PdmDescendantObjectRequest.FromString,
                    response_serializer=PdmObject__pb2.PdmObjectArray.SerializeToString,
            ),
            'GetChildPdmObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChildPdmObjects,
                    request_deserializer=PdmObject__pb2.PdmChildObjectRequest.FromString,
                    response_serializer=PdmObject__pb2.PdmObjectArray.SerializeToString,
            ),
            'GetAncestorPdmObject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAncestorPdmObject,
                    request_deserializer=PdmObject__pb2.PdmParentObjectRequest.FromString,
                    response_serializer=PdmObject__pb2.PdmObject.SerializeToString,
            ),
            'CreateChildPdmObject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateChildPdmObject,
                    request_deserializer=PdmObject__pb2.CreatePdmChildObjectRequest.FromString,
                    response_serializer=PdmObject__pb2.PdmObject.SerializeToString,
            ),
            'UpdateExistingPdmObject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateExistingPdmObject,
                    request_deserializer=PdmObject__pb2.PdmObject.FromString,
                    response_serializer=Definitions__pb2.Empty.SerializeToString,
            ),
            'CallPdmObjectGetter': grpc.unary_stream_rpc_method_handler(
                    servicer.CallPdmObjectGetter,
                    request_deserializer=PdmObject__pb2.PdmObjectGetterRequest.FromString,
                    response_serializer=PdmObject__pb2.PdmObjectGetterReply.SerializeToString,
            ),
            'CallPdmObjectSetter': grpc.stream_unary_rpc_method_handler(
                    servicer.CallPdmObjectSetter,
                    request_deserializer=PdmObject__pb2.PdmObjectSetterChunk.FromString,
                    response_serializer=Definitions__pb2.ClientToServerStreamReply.SerializeToString,
            ),
            'CallPdmObjectMethod': grpc.unary_unary_rpc_method_handler(
                    servicer.CallPdmObjectMethod,
                    request_deserializer=PdmObject__pb2.PdmObjectMethodRequest.FromString,
                    response_serializer=PdmObject__pb2.PdmObject.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'rips.PdmObjectService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PdmObjectService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDescendantPdmObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.PdmObjectService/GetDescendantPdmObjects',
            PdmObject__pb2.PdmDescendantObjectRequest.SerializeToString,
            PdmObject__pb2.PdmObjectArray.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChildPdmObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.PdmObjectService/GetChildPdmObjects',
            PdmObject__pb2.PdmChildObjectRequest.SerializeToString,
            PdmObject__pb2.PdmObjectArray.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAncestorPdmObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.PdmObjectService/GetAncestorPdmObject',
            PdmObject__pb2.PdmParentObjectRequest.SerializeToString,
            PdmObject__pb2.PdmObject.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateChildPdmObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.PdmObjectService/CreateChildPdmObject',
            PdmObject__pb2.CreatePdmChildObjectRequest.SerializeToString,
            PdmObject__pb2.PdmObject.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateExistingPdmObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.PdmObjectService/UpdateExistingPdmObject',
            PdmObject__pb2.PdmObject.SerializeToString,
            Definitions__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CallPdmObjectGetter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.PdmObjectService/CallPdmObjectGetter',
            PdmObject__pb2.PdmObjectGetterRequest.SerializeToString,
            PdmObject__pb2.PdmObjectGetterReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CallPdmObjectSetter(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/rips.PdmObjectService/CallPdmObjectSetter',
            PdmObject__pb2.PdmObjectSetterChunk.SerializeToString,
            Definitions__pb2.ClientToServerStreamReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CallPdmObjectMethod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.PdmObjectService/CallPdmObjectMethod',
            PdmObject__pb2.PdmObjectMethodRequest.SerializeToString,
            PdmObject__pb2.PdmObject.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Access to environment variables
import os

# Load ResInsight Processing Server Client Library
import rips

# Connect to ResInsight instance
resinsight = rips.Instance.launch()

# This requires the TestModels to be installed with ResInsight (RESINSIGHT_BUNDLE_TESTMODELS):
resinsight_exe_path = os.environ.get("RESINSIGHT_EXECUTABLE")

# Get the TestModels path from the executable path
resinsight_install_path = os.path.dirname(resinsight_exe_path)
test_models_path = os.path.join(resinsight_install_path, "TestModels")
path_name = os.path.join(
    test_models_path, "TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
)

# Load an example case. Needs to be replaced with a valid path!
case = resinsight.project.load_case(path_name)

# Get a view
view1 = case.views()[0]

# Set the time step for view1 only
view1.set_time_step(time_step=2)

# Set cell result to SOIL
view1.apply_cell_result(result_type="DYNAMIC_NATIVE", result_variable="SOIL")

# Set export folder for snapshots and properties
resinsight.set_export_folder(export_type="SNAPSHOTS", path="e:/temp")
resinsight.set_export_folder(export_type="PROPERTIES", path="e:/temp")

# Export all snapshots
resinsight.project.export_snapshots()

# Export properties in the view
view1.export_property()

resinsight.exit()



name = "rips"

import os
import sys

sys.path.insert(0, os.path.join(os.path.dirname(__file__), "generated"))

from .resinsight_classes import *

from .case import Case, EclipseCase, GeoMechCase
from .grid import Grid
from .instance import Instance
from .view import View
from .project import Project
from .plot import Plot, PlotWindow
from .contour_map import EclipseContourMap, GeoMechContourMap
from .well_log_plot import WellLogPlot
from .simulation_well import SimulationWell

__all__ = []
for key in class_dict():
    __all__.append(key)

# Add classes not in resinsight_classes
__all__.append("Grid")
__all__.append("Instance")

__all__.sort()



# Access to environment variables and path tools
import os

# Load ResInsight Processing Server Client Library
import rips

# Connect to ResInsight instance
resinsight = rips.Instance.find()

# This requires the TestModels to be installed with ResInsight (RESINSIGHT_BUNDLE_TESTMODELS):
resinsight_exe_path = os.environ.get("RESINSIGHT_EXECUTABLE")

# Get the TestModels path from the executable path
resinsight_install_path = os.path.dirname(resinsight_exe_path)
test_models_path = os.path.join(resinsight_install_path, "TestModels")
path_name = os.path.join(test_models_path, "TEST10K_FLT_LGR_NNC/10KWithWellLog.rsp")

# Open a project
resinsight.project.open(path_name)



import sys
import os
import tempfile
import pytest
import grpc

sys.path.insert(1, os.path.join(sys.path[0], "../../"))
import rips

import dataroot


def test_create_lgr_well(rips_instance, initialize_test):
    case = rips_instance.project.load_case(
        dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    )
    assert case.name == "TEST10K_FLT_LGR_NNC"
    assert len(case.grids()) == 2

    well_files = [dataroot.PATH + "/TEST10K_FLT_LGR_NNC/wellpath_a.dev"]
    rips_instance.project.import_well_paths(well_path_files=well_files)

    time_step = 5
    well_path_names = ["Well Path A"]
    case.create_lgr_for_completion(
        time_step,
        well_path_names,
        refinement_i=2,
        refinement_j=3,
        refinement_k=1,
        split_type="LGR_PER_WELL",
    )
    assert len(case.grids()) == 3



# Load ResInsight Processing Server Client Library
import math, time
import rips

resinsight = rips.Instance.find()

# The coordinates in this example is based on the Drogon test case from Equinor
file_path = "e:/models/from_equinor_sftp/drogon-real0-iter3/DROGON-0.EGRID"

case = resinsight.project.load_case(file_path)

view = case.create_view()
view.set_time_step(2)

intersection_coll = resinsight.project.descendants(rips.IntersectionCollection)[0]

# Add a CurveIntersection and set coordinates for the polyline
intersection = intersection_coll.add_new_object(rips.CurveIntersection)
intersection.points = [
    [45854, 595757, 1500],
    [46493, 534259.1, 1500],
    [46598, 590044.1, 1500],
]
intersection.update()

# Add a new modeled well path
well_path_coll = resinsight.project.descendants(rips.WellPathCollection)[0]
well_path = well_path_coll.add_new_object(rips.ModeledWellPath)
well_path.name = "Test Well-1"
well_path.update()

# Set reference coordinate
geometry = well_path.well_path_geometry()
reference_point = geometry.reference_point
reference_point[0] = 458580
reference_point[1] = 5935514
reference_point[2] = 1742
geometry.update()  # Commit updates back to ResInsight

# Create the first well target at the reference point
coord = [0, 0, 0]
geometry.append_well_target(coord)

# Append well target with fixed azimuth
coord = [2229.10, -833.74, -74.70]
target = geometry.append_well_target(
    coord, use_fixed_azimuth=True, fixed_azimuth_value=45.1
)

# Append well target with fixed inclination
coord = [3403.15, -1938.61, -80.93]
target = geometry.append_well_target(
    coord, use_fixed_inclination=True, fixed_inclination_value=115.2
)

coord = [4577.21, -3043.47, -87.15]
target = geometry.append_well_target(coord)
geometry.update()

# Read out estimated dogleg and azimuth/inclination for well targets
for w in geometry.well_path_targets():
    print(
        "DL1:{}   DL2:{}   Azi: {}   Incl: {}".format(
            w.estimated_dogleg1,
            w.estimated_dogleg2,
            w.estimated_azimuth,
            w.estimated_inclination,
        )
    )

# Add a curve intersection based on the modeled well path
well_path_intersection = intersection_coll.add_new_object(rips.CurveIntersection)
well_path_intersection.type = "CS_WELL_PATH"
well_path_intersection.well_path = well_path
well_path_intersection.update()



# pylint: disable=too-few-public-methods

"""
Module containing the Grid class, containing information
about Case grids.
"""

import Case_pb2
import Grid_pb2
import Grid_pb2_grpc


class Grid:
    """Grid Information. Created by methods in Case
    :meth:`rips.case.grid()`
    :meth:`rips.case.grids()`
    """

    def __init__(self, index, case, channel):
        self.__channel = channel
        self.__stub = Grid_pb2_grpc.GridStub(self.__channel)

        self.case = case
        self.index = index
        self.cached_dimensions = None

    def dimensions(self):
        """The dimensions in i, j, k direction

        Returns:
            Vec3i: class with integer attributes i, j, k giving extent in all three dimensions.
        """
        case_request = Case_pb2.CaseRequest(id=self.case.id)

        if self.cached_dimensions is None:
            self.cached_dimensions = self.__stub.GetDimensions(
                Grid_pb2.GridRequest(case_request=case_request, grid_index=self.index)
            ).dimensions

        return self.cached_dimensions

    def cell_centers_async(self):
        """The cells center for all cells in given grid async.

        Returns:
            Iterator to a list of Vec3d: class with double attributes x, y, x giving cell centers
        """
        case_request = Case_pb2.CaseRequest(id=self.case.id)
        chunks = self.__stub.GetCellCenters(
            Grid_pb2.GridRequest(case_request=case_request, grid_index=self.index)
        )
        for chunk in chunks:
            yield chunk

    def cell_centers(self):
        """The cell center for all cells in given grid

        Returns:
            List of Vec3d: class with double attributes x, y, x giving cell centers
        """
        centers = []
        chunks = self.cell_centers_async()
        for chunk in chunks:
            for center in chunk.centers:
                centers.append(center)
        return centers

    def cell_corners_async(self):
        """The cell corners for all cells in given grid, async.

        Returns:
            iterator to a list of CellCorners: a class with Vec3d for each corner (c0, c1.., c7)
        """
        case_request = Case_pb2.CaseRequest(id=self.case.id)
        chunks = self.__stub.GetCellCorners(
            Grid_pb2.GridRequest(case_request=case_request, grid_index=self.index)
        )

        for chunk in chunks:
            yield chunk

    def cell_corners(self):
        """The cell corners for all cells in given grid

        Returns:
            list of CellCorners: a class with Vec3d for each corner (c0, c1.., c7)
        """
        corners = []
        chunks = self.cell_corners_async()
        for chunk in chunks:
            for center in chunk.cells:
                corners.append(center)
        return corners

    def property_data_index_from_ijk(self, i, j, k):
        """Compute property index from 1-based IJK cell address. Cell Property Result data is organized by I, J and K.

        property_data_index = dims.i * dims.j * (k - 1) + dims.i * (j - 1) + (i - 1)

        Returns:
            int: Cell property result index from IJK
        """

        dims = self.dimensions()

        property_data_index = dims.i * dims.j * (k - 1) + dims.i * (j - 1) + (i - 1)

        return property_data_index

    def cell_count(self):
        """Cell count in grid

        Returns:
            int: Cell count in grid
        """

        dims = self.dimensions()

        count = dims.i * dims.j * dims.k

        return count



# Load ResInsight Processing Server Client Library
import rips

# Connect to ResInsight instance
resinsight = rips.Instance.find()
# Example code

# Specific summary case with case_id = 1
summary_case = resinsight.project.summary_case(case_id=1)
summary_case.print_object_info()

# All summary cases
summary_cases = resinsight.project.summary_cases()
for summary_case in summary_cases:
    print("Summary case found: ", summary_case.short_name)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import Definitions_pb2 as Definitions__pb2
import Properties_pb2 as Properties__pb2


class PropertiesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAvailableProperties = channel.unary_unary(
                '/rips.Properties/GetAvailableProperties',
                request_serializer=Properties__pb2.AvailablePropertiesRequest.SerializeToString,
                response_deserializer=Properties__pb2.AvailableProperties.FromString,
                )
        self.GetActiveCellProperty = channel.unary_stream(
                '/rips.Properties/GetActiveCellProperty',
                request_serializer=Properties__pb2.PropertyRequest.SerializeToString,
                response_deserializer=Properties__pb2.PropertyChunk.FromString,
                )
        self.GetSelectedCellProperty = channel.unary_stream(
                '/rips.Properties/GetSelectedCellProperty',
                request_serializer=Properties__pb2.PropertyRequest.SerializeToString,
                response_deserializer=Properties__pb2.PropertyChunk.FromString,
                )
        self.GetGridProperty = channel.unary_stream(
                '/rips.Properties/GetGridProperty',
                request_serializer=Properties__pb2.PropertyRequest.SerializeToString,
                response_deserializer=Properties__pb2.PropertyChunk.FromString,
                )
        self.SetActiveCellProperty = channel.stream_unary(
                '/rips.Properties/SetActiveCellProperty',
                request_serializer=Properties__pb2.PropertyInputChunk.SerializeToString,
                response_deserializer=Definitions__pb2.ClientToServerStreamReply.FromString,
                )
        self.SetGridProperty = channel.stream_unary(
                '/rips.Properties/SetGridProperty',
                request_serializer=Properties__pb2.PropertyInputChunk.SerializeToString,
                response_deserializer=Definitions__pb2.ClientToServerStreamReply.FromString,
                )


class PropertiesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAvailableProperties(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveCellProperty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelectedCellProperty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGridProperty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetActiveCellProperty(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetGridProperty(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PropertiesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAvailableProperties': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableProperties,
                    request_deserializer=Properties__pb2.AvailablePropertiesRequest.FromString,
                    response_serializer=Properties__pb2.AvailableProperties.SerializeToString,
            ),
            'GetActiveCellProperty': grpc.unary_stream_rpc_method_handler(
                    servicer.GetActiveCellProperty,
                    request_deserializer=Properties__pb2.PropertyRequest.FromString,
                    response_serializer=Properties__pb2.PropertyChunk.SerializeToString,
            ),
            'GetSelectedCellProperty': grpc.unary_stream_rpc_method_handler(
                    servicer.GetSelectedCellProperty,
                    request_deserializer=Properties__pb2.PropertyRequest.FromString,
                    response_serializer=Properties__pb2.PropertyChunk.SerializeToString,
            ),
            'GetGridProperty': grpc.unary_stream_rpc_method_handler(
                    servicer.GetGridProperty,
                    request_deserializer=Properties__pb2.PropertyRequest.FromString,
                    response_serializer=Properties__pb2.PropertyChunk.SerializeToString,
            ),
            'SetActiveCellProperty': grpc.stream_unary_rpc_method_handler(
                    servicer.SetActiveCellProperty,
                    request_deserializer=Properties__pb2.PropertyInputChunk.FromString,
                    response_serializer=Definitions__pb2.ClientToServerStreamReply.SerializeToString,
            ),
            'SetGridProperty': grpc.stream_unary_rpc_method_handler(
                    servicer.SetGridProperty,
                    request_deserializer=Properties__pb2.PropertyInputChunk.FromString,
                    response_serializer=Definitions__pb2.ClientToServerStreamReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'rips.Properties', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Properties(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAvailableProperties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Properties/GetAvailableProperties',
            Properties__pb2.AvailablePropertiesRequest.SerializeToString,
            Properties__pb2.AvailableProperties.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveCellProperty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Properties/GetActiveCellProperty',
            Properties__pb2.PropertyRequest.SerializeToString,
            Properties__pb2.PropertyChunk.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSelectedCellProperty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Properties/GetSelectedCellProperty',
            Properties__pb2.PropertyRequest.SerializeToString,
            Properties__pb2.PropertyChunk.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGridProperty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Properties/GetGridProperty',
            Properties__pb2.PropertyRequest.SerializeToString,
            Properties__pb2.PropertyChunk.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetActiveCellProperty(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/rips.Properties/SetActiveCellProperty',
            Properties__pb2.PropertyInputChunk.SerializeToString,
            Definitions__pb2.ClientToServerStreamReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetGridProperty(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/rips.Properties/SetGridProperty',
            Properties__pb2.PropertyInputChunk.SerializeToString,
            Definitions__pb2.ClientToServerStreamReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc


class RetryOnRpcErrorClientInterceptor(
    grpc.UnaryUnaryClientInterceptor, grpc.StreamUnaryClientInterceptor
):
    def __init__(
        self,
        *,
        retry_policy,
        status_for_retry,
    ):
        self.retry_policy = retry_policy
        self.status_for_retry = status_for_retry

    def _intercept_call(self, continuation, client_call_details, request_or_iterator):
        for retry_num in range(self.retry_policy.num_retries()):
            response = continuation(client_call_details, request_or_iterator)

            if isinstance(response, grpc.RpcError):
                # Return if it was last attempt
                if retry_num == (self.retry_policy.num_retries() - 1):
                    return response

                # If status code is not in retryable status codes
                if (
                    self.status_for_retry
                    and response.code() not in self.status_for_retry
                ):
                    return response

                self.retry_policy.sleep(retry_num)
            else:
                return response

    def intercept_unary_unary(self, continuation, client_call_details, request):
        return self._intercept_call(continuation, client_call_details, request)

    def intercept_stream_unary(
        self, continuation, client_call_details, request_iterator
    ):
        return self._intercept_call(continuation, client_call_details, request_iterator)



import abc

import time
import random


class RetryPolicy(abc.ABC):
    @abc.abstractmethod
    def sleep(self, retry_num):
        """
        How long to sleep in milliseconds.
        :param retry_num: the number of retry (starting from zero)
        """
        assert retry_num >= 0

    @abc.abstractmethod
    def time_out_message(self):
        """
        Generate a error message for user on time out.
        """
        pass

    @abc.abstractmethod
    def num_retries(self):
        """
        Max number retries.
        """
        pass


class FixedRetryPolicy(RetryPolicy):
    def __init__(self, sleep_time=1000, max_num_retries=10):
        """
        Create a fixed time retry policy.
        :param sleep_time: time to sleep in milliseconds.
        :param max_num_retries: max number of retries.
        """
        self.sleep_time = sleep_time
        self.max_num_retries = max_num_retries

    def sleep(self, retry_num):
        time.sleep(self.sleep_time / 1000)

    def time_out_message(self):
        return "Tried {} times with {} milliseconds apart.".format(
            self.max_num_retries, self.sleep_time
        )

    def num_retries(self):
        return self.max_num_retries


class ExponentialBackoffRetryPolicy(RetryPolicy):
    def __init__(self, min_backoff=200, max_backoff=10000, max_num_retries=20):
        """
        Create a truncated exponential backoff policy.
        See: https://en.wikipedia.org/wiki/Exponential_backoff
        :param min_backoff: minimum time to sleep in milliseconds.
        :param max_backoff: maximum time to sleep in milliseconds.
        :param max_num_retries: max number of retries.
        """
        self.min_backoff = min_backoff
        self.max_backoff = max_backoff
        self.max_num_retries = max_num_retries
        self.multiplier = 2

    def sleep(self, retry_num):
        # Add a random component to avoid synchronized retries
        wiggle = random.randint(0, 100)
        sleep_ms = min(
            self.min_backoff + self.multiplier**retry_num + wiggle, self.max_backoff
        )
        time.sleep(sleep_ms / 1000)

    def time_out_message(self):
        return (
            "Tried {} times with increasing delay (from {} to {} milliseconds).".format(
                self.max_num_retries, self.min_backoff, self.max_backoff
            )
        )

    def num_retries(self):
        return self.max_num_retries



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Definitions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x44\x65\x66initions.proto\x12\x04rips\"\x07\n\x05\x45mpty\"9\n\x19\x43lientToServerStreamReply\x12\x1c\n\x14\x61\x63\x63\x65pted_value_count\x18\x01 \x01(\x03\"(\n\x05Vec3i\x12\t\n\x01i\x18\x01 \x01(\x05\x12\t\n\x01j\x18\x02 \x01(\x05\x12\t\n\x01k\x18\x03 \x01(\x05\"(\n\x05Vec3d\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"+\n\x0b\x43\x65llCenters\x12\x1c\n\x07\x63\x65nters\x18\x01 \x03(\x0b\x32\x0b.rips.Vec3d\"\xd5\x01\n\x0b\x43\x65llCorners\x12\x17\n\x02\x63\x30\x18\x01 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x31\x18\x02 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x32\x18\x03 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x33\x18\x04 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x34\x18\x05 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x35\x18\x06 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x36\x18\x07 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x37\x18\x08 \x01(\x0b\x32\x0b.rips.Vec3d\"4\n\x10\x43\x65llCornersArray\x12 \n\x05\x63\x65lls\x18\x01 \x03(\x0b\x32\x11.rips.CellCornersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Definitions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EMPTY']._serialized_start=27
  _globals['_EMPTY']._serialized_end=34
  _globals['_CLIENTTOSERVERSTREAMREPLY']._serialized_start=36
  _globals['_CLIENTTOSERVERSTREAMREPLY']._serialized_end=93
  _globals['_VEC3I']._serialized_start=95
  _globals['_VEC3I']._serialized_end=135
  _globals['_VEC3D']._serialized_start=137
  _globals['_VEC3D']._serialized_end=177
  _globals['_CELLCENTERS']._serialized_start=179
  _globals['_CELLCENTERS']._serialized_end=222
  _globals['_CELLCORNERS']._serialized_start=225
  _globals['_CELLCORNERS']._serialized_end=438
  _globals['_CELLCORNERSARRAY']._serialized_start=440
  _globals['_CELLCORNERSARRAY']._serialized_end=492
# @@protoc_insertion_point(module_scope)



# Load ResInsight Processing Server Client Library
import rips

# Connect to ResInsight instance
resinsight = rips.Instance.find()
print("ResInsight version: " + resinsight.version_string())

# Example code

# get the project
project = resinsight.project

# get the topmost surface folder from the project
surfacefolder = project.surface_folder()

# list of surface files to load
filenames = ["surface1.ts", "surface2.ts", "surface3.ts"]

# Load the files into the top level
for surffile in filenames:
    surface = surfacefolder.import_surface(surffile)
    if surface is None:
        print("Could not import the surface " + surffile)

# add a subfolder
subfolder = surfacefolder.add_folder("ExampleFolder")

# load the same surface multiple times using increasing depth offsets
# store them in the new subfolder we just created
for offset in range(0, 200, 20):
    surface = subfolder.import_surface("mysurface.ts")
    if surface:
        surface.depth_offset = offset
        surface.update()
    else:
        print("Could not import surface.")

# get an existing subfolder
existingfolder = project.surface_folder("ExistingFolder")
if existingfolder is None:
    print("Could not find the specified folder.")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PdmObject.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fPdmObject.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\"T\n\x1aPdmDescendantObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x15\n\rchild_keyword\x18\x02 \x01(\t\"M\n\x15PdmChildObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x13\n\x0b\x63hild_field\x18\x02 \x01(\t\"j\n\x1b\x43reatePdmChildObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x13\n\x0b\x63hild_field\x18\x02 \x01(\t\x12\x15\n\rclass_keyword\x18\x03 \x01(\t\"Q\n\x16PdmParentObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x16\n\x0eparent_keyword\x18\x02 \x01(\t\"\xc0\x01\n\tPdmObject\x12\x15\n\rclass_keyword\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x04\x12\x33\n\nparameters\x18\x03 \x03(\x0b\x32\x1f.rips.PdmObject.ParametersEntry\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12\x12\n\npersistent\x18\x05 \x01(\x08\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x0ePdmObjectArray\x12 \n\x07objects\x18\x01 \x03(\x0b\x32\x0f.rips.PdmObject\"I\n\x16PdmObjectGetterRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x0e\n\x06method\x18\x02 \x01(\t\"[\n\x16PdmObjectSetterRequest\x12-\n\x07request\x18\x01 \x01(\x0b\x32\x1c.rips.PdmObjectGetterRequest\x12\x12\n\ndata_count\x18\x02 \x01(\x05\"\xbf\x01\n\x14PdmObjectSetterChunk\x12\x33\n\x0bset_request\x18\x01 \x01(\x0b\x32\x1c.rips.PdmObjectSetterRequestH\x00\x12$\n\x07\x64oubles\x18\x02 \x01(\x0b\x32\x11.rips.DoubleArrayH\x00\x12\x1e\n\x04ints\x18\x03 \x01(\x0b\x32\x0e.rips.IntArrayH\x00\x12$\n\x07strings\x18\x04 \x01(\x0b\x32\x11.rips.StringArrayH\x00\x42\x06\n\x04\x64\x61ta\"\x1b\n\x0b\x44oubleArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"\x18\n\x08IntArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"\x1b\n\x0bStringArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"\x8a\x01\n\x14PdmObjectGetterReply\x12$\n\x07\x64oubles\x18\x01 \x01(\x0b\x32\x11.rips.DoubleArrayH\x00\x12\x1e\n\x04ints\x18\x02 \x01(\x0b\x32\x0e.rips.IntArrayH\x00\x12$\n\x07strings\x18\x03 \x01(\x0b\x32\x11.rips.StringArrayH\x00\x42\x06\n\x04\x64\x61ta\"j\n\x16PdmObjectMethodRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x1f\n\x06params\x18\x03 \x01(\x0b\x32\x0f.rips.PdmObject2\xf9\x04\n\x10PdmObjectService\x12S\n\x17GetDescendantPdmObjects\x12 .rips.PdmDescendantObjectRequest\x1a\x14.rips.PdmObjectArray\"\x00\x12I\n\x12GetChildPdmObjects\x12\x1b.rips.PdmChildObjectRequest\x1a\x14.rips.PdmObjectArray\"\x00\x12G\n\x14GetAncestorPdmObject\x12\x1c.rips.PdmParentObjectRequest\x1a\x0f.rips.PdmObject\"\x00\x12L\n\x14\x43reateChildPdmObject\x12!.rips.CreatePdmChildObjectRequest\x1a\x0f.rips.PdmObject\"\x00\x12\x39\n\x17UpdateExistingPdmObject\x12\x0f.rips.PdmObject\x1a\x0b.rips.Empty\"\x00\x12S\n\x13\x43\x61llPdmObjectGetter\x12\x1c.rips.PdmObjectGetterRequest\x1a\x1a.rips.PdmObjectGetterReply\"\x00\x30\x01\x12V\n\x13\x43\x61llPdmObjectSetter\x12\x1a.rips.PdmObjectSetterChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x12\x46\n\x13\x43\x61llPdmObjectMethod\x12\x1c.rips.PdmObjectMethodRequest\x1a\x0f.rips.PdmObject\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PdmObject_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PDMOBJECT_PARAMETERSENTRY._options = None
  _PDMOBJECT_PARAMETERSENTRY._serialized_options = b'8\001'
  _globals['_PDMDESCENDANTOBJECTREQUEST']._serialized_start=44
  _globals['_PDMDESCENDANTOBJECTREQUEST']._serialized_end=128
  _globals['_PDMCHILDOBJECTREQUEST']._serialized_start=130
  _globals['_PDMCHILDOBJECTREQUEST']._serialized_end=207
  _globals['_CREATEPDMCHILDOBJECTREQUEST']._serialized_start=209
  _globals['_CREATEPDMCHILDOBJECTREQUEST']._serialized_end=315
  _globals['_PDMPARENTOBJECTREQUEST']._serialized_start=317
  _globals['_PDMPARENTOBJECTREQUEST']._serialized_end=398
  _globals['_PDMOBJECT']._serialized_start=401
  _globals['_PDMOBJECT']._serialized_end=593
  _globals['_PDMOBJECT_PARAMETERSENTRY']._serialized_start=544
  _globals['_PDMOBJECT_PARAMETERSENTRY']._serialized_end=593
  _globals['_PDMOBJECTARRAY']._serialized_start=595
  _globals['_PDMOBJECTARRAY']._serialized_end=645
  _globals['_PDMOBJECTGETTERREQUEST']._serialized_start=647
  _globals['_PDMOBJECTGETTERREQUEST']._serialized_end=720
  _globals['_PDMOBJECTSETTERREQUEST']._serialized_start=722
  _globals['_PDMOBJECTSETTERREQUEST']._serialized_end=813
  _globals['_PDMOBJECTSETTERCHUNK']._serialized_start=816
  _globals['_PDMOBJECTSETTERCHUNK']._serialized_end=1007
  _globals['_DOUBLEARRAY']._serialized_start=1009
  _globals['_DOUBLEARRAY']._serialized_end=1036
  _globals['_INTARRAY']._serialized_start=1038
  _globals['_INTARRAY']._serialized_end=1062
  _globals['_STRINGARRAY']._serialized_start=1064
  _globals['_STRINGARRAY']._serialized_end=1091
  _globals['_PDMOBJECTGETTERREPLY']._serialized_start=1094
  _globals['_PDMOBJECTGETTERREPLY']._serialized_end=1232
  _globals['_PDMOBJECTMETHODREQUEST']._serialized_start=1234
  _globals['_PDMOBJECTMETHODREQUEST']._serialized_end=1340
  _globals['_PDMOBJECTSERVICE']._serialized_start=1343
  _globals['_PDMOBJECTSERVICE']._serialized_end=1976
# @@protoc_insertion_point(module_scope)



#############################################################
# This example will alter the views of all cases
# By setting the background color and toggle the grid box
# Also clones the first view
#############################################################
import rips

# Connect to ResInsight instance
resinsight = rips.Instance.find()

# Check if connection worked
if resinsight is not None:
    # Get a list of all cases
    cases = resinsight.project.cases()
    for case in cases:
        # Get a list of all views
        views = case.views()
        for view in views:
            # Set some parameters for the view
            view.show_grid_box = not view.show_grid_box
            view.background_color = "#3388AA"
            # Update the view in ResInsight
            view.update()
        # Clone the first view
        new_view = views[0].clone()
        new_view.background_color = "#FFAA33"
        new_view.update()
        view.show_grid_box = False
        view.set_visible(False)
        view.update()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: NNCProperties.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Case_pb2 as Case__pb2
import Definitions_pb2 as Definitions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13NNCProperties.proto\x12\x04rips\x1a\nCase.proto\x1a\x11\x44\x65\x66initions.proto\"R\n\x14\x41vailableNNCProperty\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\rproperty_type\x18\x02 \x01(\x0e\x32\x15.rips.NNCPropertyType\"H\n\x16\x41vailableNNCProperties\x12.\n\nproperties\x18\x01 \x03(\x0b\x32\x1a.rips.AvailableNNCProperty\"{\n\rNNCConnection\x12\x18\n\x10\x63\x65ll_grid_index1\x18\x01 \x01(\x05\x12\x18\n\x10\x63\x65ll_grid_index2\x18\x02 \x01(\x05\x12\x1a\n\x05\x63\x65ll1\x18\x03 \x01(\x0b\x32\x0b.rips.Vec3i\x12\x1a\n\x05\x63\x65ll2\x18\x04 \x01(\x0b\x32\x0b.rips.Vec3i\":\n\x0eNNCConnections\x12(\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\x13.rips.NNCConnection\"{\n\x10NNCValuesRequest\x12\x0f\n\x07\x63\x61se_id\x18\x01 \x01(\x05\x12\x15\n\rproperty_name\x18\x02 \x01(\t\x12,\n\rproperty_type\x18\x03 \x01(\x0e\x32\x15.rips.NNCPropertyType\x12\x11\n\ttime_step\x18\x04 \x01(\x05\"\x1b\n\tNNCValues\x12\x0e\n\x06values\x18\x01 \x03(\x01\"\x83\x01\n\x15NNCValuesInputRequest\x12\x0f\n\x07\x63\x61se_id\x18\x01 \x01(\x05\x12\x15\n\rproperty_name\x18\x02 \x01(\t\x12/\n\x0eporosity_model\x18\x03 \x01(\x0e\x32\x17.rips.PorosityModelType\x12\x11\n\ttime_step\x18\x04 \x01(\x05\"o\n\x0eNNCValuesChunk\x12-\n\x06params\x18\x01 \x01(\x0b\x32\x1b.rips.NNCValuesInputRequestH\x00\x12!\n\x06values\x18\x02 \x01(\x0b\x32\x0f.rips.NNCValuesH\x00\x42\x0b\n\tChunkType*E\n\x0fNNCPropertyType\x12\x0f\n\x0bNNC_DYNAMIC\x10\x00\x12\x0e\n\nNNC_STATIC\x10\x01\x12\x11\n\rNNC_GENERATED\x10\x02\x32\xa9\x02\n\rNNCProperties\x12N\n\x19GetAvailableNNCProperties\x12\x11.rips.CaseRequest\x1a\x1c.rips.AvailableNNCProperties\"\x00\x12@\n\x11GetNNCConnections\x12\x11.rips.CaseRequest\x1a\x14.rips.NNCConnections\"\x00\x30\x01\x12;\n\x0cGetNNCValues\x12\x16.rips.NNCValuesRequest\x1a\x0f.rips.NNCValues\"\x00\x30\x01\x12I\n\x0cSetNNCValues\x12\x14.rips.NNCValuesChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'NNCProperties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NNCPROPERTYTYPE']._serialized_start=804
  _globals['_NNCPROPERTYTYPE']._serialized_end=873
  _globals['_AVAILABLENNCPROPERTY']._serialized_start=60
  _globals['_AVAILABLENNCPROPERTY']._serialized_end=142
  _globals['_AVAILABLENNCPROPERTIES']._serialized_start=144
  _globals['_AVAILABLENNCPROPERTIES']._serialized_end=216
  _globals['_NNCCONNECTION']._serialized_start=218
  _globals['_NNCCONNECTION']._serialized_end=341
  _globals['_NNCCONNECTIONS']._serialized_start=343
  _globals['_NNCCONNECTIONS']._serialized_end=401
  _globals['_NNCVALUESREQUEST']._serialized_start=403
  _globals['_NNCVALUESREQUEST']._serialized_end=526
  _globals['_NNCVALUES']._serialized_start=528
  _globals['_NNCVALUES']._serialized_end=555
  _globals['_NNCVALUESINPUTREQUEST']._serialized_start=558
  _globals['_NNCVALUESINPUTREQUEST']._serialized_end=689
  _globals['_NNCVALUESCHUNK']._serialized_start=691
  _globals['_NNCVALUESCHUNK']._serialized_end=802
  _globals['_NNCPROPERTIES']._serialized_start=876
  _globals['_NNCPROPERTIES']._serialized_end=1173
# @@protoc_insertion_point(module_scope)



# Load ResInsight Processing Server Client Library
import rips
import tempfile

# Connect to ResInsight instance
resinsight = rips.Instance.find()

# Get the project
project = resinsight.project

# Find all the well bore stability plots in the project
wbsplots = project.descendants(rips.WellBoreStabilityPlot)

# Chose a sensible output folder
dirname = tempfile.gettempdir()

# Loop through all Well Bore Stability plots
for wbsplot in wbsplots:
    # Set depth type a parameter and export snapshot
    wbsplot.depth_type = "TRUE_VERTICAL_DEPTH_RKB"

    # Example of setting parameters for existing plots
    params = wbsplot.parameters()
    params.user_poisson_ratio = 0.12345
    params.update()
    wbsplot.update()
    wbsplot.export_snapshot(export_folder=dirname)



###############################################################################
# This example will get the cell info for the active cells for the first case
###############################################################################

# Import the ResInsight Processing Server Module
import rips

# Connect to ResInsight
resinsight = rips.Instance.find()

# Get the first case. This will fail if you haven't loaded any cases
case = resinsight.project.cases()[0]

# Get the cell count object
cell_counts = case.cell_count()
print("Number of active cells: " + str(cell_counts.active_cell_count))
print("Total number of reservoir cells: " + str(cell_counts.reservoir_cell_count))

# Get information for all active cells
active_cell_infos = case.cell_info_for_active_cells()

# A simple check on the size of the cell info
assert cell_counts.active_cell_count == len(active_cell_infos)

# Print information for the first active cell
print("First active cell: ")
print(active_cell_infos[0])



#!/usr/bin/env python
# coding: utf-8

import rips
import tempfile
from os.path import expanduser
from pathlib import Path
import numpy as np
import pyvista as pv


def generate_surface_from_file(path):
    point_cloud_data = np.loadtxt(path, delimiter=" ", skiprows=1)

    # Get [x, y, z] components in separate matrix
    num_rows = point_cloud_data.shape[0]
    xyz = point_cloud_data[0:num_rows, 0:3]

    # Generate surface
    cloud = pv.PolyData(xyz)
    surf = cloud.delaunay_2d()

    # Read properties names from header data
    f = open(path)
    header = f.readline()
    properties = header.strip().split(" ")

    return (surf, point_cloud_data, properties)


def export_surface_as_ts_file(surf, point_cloud, properties, path):
    # open text file
    text_file = open(path, "w")

    # write GOCAD header
    top_header = """GOCAD TSurf 1
HEADER {
name:MF_027_SU
}
"""

    properties_str = "PROPERTIES " + " ".join(properties)

    bottom_header = """
GOCAD_ORIGINAL_COORDINATE_SYSTEM
NAME Default
AXIS_NAME "X" "Y" "Z"
AXIS_UNIT "m" "m" "m"
ZPOSITIVE Depth
END_ORIGINAL_COORDINATE_SYSTEM
TFACE
"""

    text_file.write(top_header)
    text_file.write(properties_str)
    text_file.write(bottom_header)

    i = 1
    (num_rows, num_props) = point_cloud.shape
    for row in range(0, num_rows):
        x = point_cloud[row, 0]
        y = point_cloud[row, 1]
        z = point_cloud[row, 2]
        txt = "PVRTX {} {:.3f} {:.3f} {:.3f} ".format(i, x, y, z)
        for property_index in range(0, num_props):
            txt += "{:.3f} ".format(point_cloud[row, property_index])
        txt += "\n"
        text_file.write(txt)
        i += 1

    mysurface = surf.faces.reshape(-1, 4)
    for p in mysurface:
        txt = "TRGL {} {} {}\n".format(p[1] + 1, p[2] + 1, p[3] + 1)
        text_file.write(txt)

    text_file.write("END")
    text_file.close()


# Connect to ResInsight instance
resinsight = rips.Instance.find()
project = resinsight.project


fractures = project.descendants(rips.ThermalFractureTemplate)
print("Number of thermal fractures: ", len(fractures))


temp_folder = tempfile.gettempdir()

# Write results to a suitable directory
home_dir = expanduser("~")

for fracture in fractures:
    fracture_name = fracture.user_description

    # Create the ouput directory
    output_directory = (
        Path(home_dir) / "thermal_fracture_surfaces" / "{}".format(fracture_name)
    )

    output_directory.mkdir(parents=True, exist_ok=True)
    print("Creating result directory: ", output_directory.as_posix())

    time_steps = fracture.time_steps().values
    for time_step_index, time_step in enumerate(time_steps):
        print(
            "Generating surface for time step #{}: {}".format(
                time_step_index, time_step
            )
        )
        temp_file_path = Path(temp_folder) / "output.xyz"
        fracture.export_to_file(
            file_path=temp_file_path.as_posix(), time_step=time_step_index
        )

        # Reconstruct a surface from the exported values file
        (surface, point_cloud, properties) = generate_surface_from_file(
            temp_file_path.as_posix()
        )

        # Export surface ts file from the surface data
        output_file_path = output_directory / "time_step_{:03d}.ts".format(
            time_step_index
        )
        export_surface_as_ts_file(
            surface, point_cloud, properties, output_file_path.as_posix()
        )
        print(
            "Wrote surface for time step #{} to {}".format(
                time_step, output_file_path.as_posix()
            )
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Commands.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Case_pb2 as Case__pb2
import Definitions_pb2 as Definitions__pb2
import PdmObject_pb2 as PdmObject__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x43ommands.proto\x12\x04rips\x1a\nCase.proto\x1a\x11\x44\x65\x66initions.proto\x1a\x0fPdmObject.proto\"1\n\x0f\x46ilePathRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x10\n\x08gridOnly\x18\x02 \x01(\x08\"9\n\x12ReplaceCaseRequest\x12\x13\n\x0bnewGridFile\x18\x01 \x01(\t\x12\x0e\n\x06\x63\x61seId\x18\x02 \x01(\x05\"B\n\x13ReplaceCaseRequests\x12+\n\tcasePairs\x18\x01 \x03(\x0b\x32\x18.rips.ReplaceCaseRequest\"F\n\x19ReplaceSourceCasesRequest\x12\x14\n\x0cgridListFile\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61seGroupId\x18\x02 \x01(\x05\".\n\x16\x45xportMultiCaseRequest\x12\x14\n\x0cgridListFile\x18\x01 \x01(\t\"\xb2\x01\n\x16\x45xportSnapshotsRequest\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.rips.SnapshotType\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61seId\x18\x03 \x01(\x05\x12\x0e\n\x06viewId\x18\x04 \x01(\x05\x12\x14\n\x0c\x65xportFolder\x18\x05 \x01(\t\x12\x30\n\x10plotOutputFormat\x18\x06 \x01(\x0e\x32\x16.rips.PlotOutputFormat\"\x8f\x01\n\x15\x45xportPropertyRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x10\n\x08property\x18\x03 \x01(\t\x12\x16\n\x0e\x65\x63lipseKeyword\x18\x04 \x01(\t\x12\x16\n\x0eundefinedValue\x18\x05 \x01(\x01\x12\x12\n\nexportFile\x18\x06 \x01(\t\"W\n\x1c\x45xportPropertyInViewsRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0f\n\x07viewIds\x18\x02 \x03(\x05\x12\x16\n\x0eundefinedValue\x18\x03 \x01(\x01\"\x8b\x03\n\x19\x45xportWellPathCompRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12+\n\tfileSplit\x18\x04 \x01(\x0e\x32\x18.rips.CompdatExportSplit\x12.\n\rcompdatExport\x18\x05 \x01(\x0e\x32\x17.rips.CompdatExportType\x12\x1b\n\x13includePerforations\x18\x06 \x01(\x08\x12\x18\n\x10includeFishbones\x18\x07 \x01(\x08\x12#\n\x1b\x65xcludeMainBoreForFishbones\x18\x08 \x01(\x08\x12\x35\n\x0f\x63ombinationMode\x18\t \x01(\x0e\x32\x1c.rips.CompdatCombinationMode\x12\x16\n\x0e\x63ustomFileName\x18\n \x01(\t\x12\x16\n\x0e\x65xportComments\x18\x0b \x01(\x08\x12\x15\n\rexportWelspec\x18\x0c \x01(\x08\"\xca\x01\n\x1c\x45xportSimWellPathFracRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\x12\x1b\n\x13simulationWellNames\x18\x04 \x03(\t\x12+\n\tfileSplit\x18\x05 \x01(\x0e\x32\x18.rips.CompdatExportSplit\x12.\n\rcompdatExport\x18\x06 \x01(\x0e\x32\x17.rips.CompdatExportType\"4\n\x10\x45xportMswRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08wellPath\x18\x02 \x01(\t\"B\n\x15\x45xportWellPathRequest\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\x12\x12\n\nmdStepSize\x18\x02 \x01(\x01\"\xaf\x01\n\x19\x45xportVisibleCellsRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x15\n\rexportKeyword\x18\x03 \x01(\t\x12\x1f\n\x17visibleActiveCellsValue\x18\x04 \x01(\x05\x12\x1e\n\x16hiddenActiveCellsValue\x18\x05 \x01(\x05\x12\x1a\n\x12inactiveCellsValue\x18\x06 \x01(\x05\"b\n\x16SetExportFolderRequest\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.rips.ExportFolderType\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0c\x63reateFolder\x18\x03 \x01(\x08\"7\n\x16RunOctaveScriptRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61seIds\x18\x02 \x03(\x05\"4\n\x13SetWindowSizeParams\x12\x0e\n\x06height\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\"C\n\x1b\x43omputeCaseGroupStatRequest\x12\x0f\n\x07\x63\x61seIds\x18\x01 \x03(\x05\x12\x13\n\x0b\x63\x61seGroupId\x18\x02 \x01(\x05\"E\n\x11SetTimeStepParams\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\"N\n\x1cScaleFractureTemplateRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nhalfLength\x18\x02 \x01(\x01\x12\x0e\n\x06height\x18\x03 \x01(\x01\"L\n\x19SetFracContainmentRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08topLayer\x18\x02 \x01(\x05\x12\x11\n\tbaseLayer\x18\x03 \x01(\x05\"\xee\x01\n\x19\x43reateMultipleFracRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x12\n\ntemplateId\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12\x19\n\x11minDistFromWellTd\x18\x04 \x01(\x01\x12\x1b\n\x13maxFracturesPerWell\x18\x05 \x01(\x05\x12\x10\n\x08topLayer\x18\x06 \x01(\x05\x12\x11\n\tbaseLayer\x18\x07 \x01(\x05\x12\x0f\n\x07spacing\x18\x08 \x01(\x05\x12(\n\x06\x61\x63tion\x18\t \x01(\x0e\x32\x18.rips.MultipleFracAction\"\xb8\x01\n\x17\x43reateLgrForCompRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12\x13\n\x0brefinementI\x18\x04 \x01(\x05\x12\x13\n\x0brefinementJ\x18\x05 \x01(\x05\x12\x13\n\x0brefinementK\x18\x06 \x01(\x05\x12%\n\tsplitType\x18\x07 \x01(\x0e\x32\x12.rips.LgrSplitType\",\n\x19\x43reateSatPressPlotRequest\x12\x0f\n\x07\x63\x61seIds\x18\x01 \x03(\x05\"/\n\x1a\x43reateGridCaseGroupRequest\x12\x11\n\tcasePaths\x18\x01 \x03(\t\"2\n\x1b\x43reateStatisticsCaseRequest\x12\x13\n\x0b\x63\x61seGroupId\x18\x01 \x01(\x05\"\xae\x01\n\x15\x45xportFlowInfoRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x11\n\ttimeSteps\x18\x02 \x03(\x05\x12\x11\n\tinjectors\x18\x03 \x03(\t\x12\x11\n\tproducers\x18\x04 \x03(\t\x12\x10\n\x08\x66ileName\x18\x05 \x01(\t\x12\x1c\n\x14minimumCommunication\x18\x06 \x01(\x01\x12\x1c\n\x14\x61quiferCellThreshold\x18\x07 \x01(\x01\"#\n\x11\x43reateViewRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\"\"\n\x10\x43loneViewRequest\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\"r\n\x14\x43reateWbsPlotRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08wellPath\x18\x02 \x01(\t\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\x12&\n\rwbsParameters\x18\x04 \x01(\x0b\x32\x0f.rips.PdmObject\"G\n\x16ImportWellPathsRequest\x12\x16\n\x0ewellPathFolder\x18\x01 \x01(\t\x12\x15\n\rwellPathFiles\x18\x02 \x03(\t\"H\n\x19ImportWellLogFilesRequest\x12\x15\n\rwellLogFolder\x18\x01 \x01(\t\x12\x14\n\x0cwellLogFiles\x18\x02 \x03(\t\"L\n\x1bImportFormationNamesRequest\x12\x16\n\x0e\x66ormationFiles\x18\x01 \x03(\t\x12\x15\n\rapplyToCaseId\x18\x02 \x01(\x05\"\xea\x01\n\x1c\x45xportWellLogPlotDataRequest\x12(\n\x0c\x65xportFormat\x18\x01 \x01(\x0e\x32\x12.rips.ExportFormat\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x14\n\x0c\x65xportFolder\x18\x03 \x01(\t\x12\x12\n\nfilePrefix\x18\x04 \x01(\t\x12\x14\n\x0c\x65xportTvdRkb\x18\x05 \x01(\x08\x12\x1b\n\x13\x63\x61pitalizeFileNames\x18\x06 \x01(\x08\x12\x18\n\x10resampleInterval\x18\x07 \x01(\x01\x12\x19\n\x11\x63onvertCurveUnits\x18\x08 \x01(\x08\"\xa4\x01\n\x1d\x45xportContourMapToTextRequest\x12\x16\n\x0e\x65xportFileName\x18\x01 \x01(\t\x12\x1e\n\x16\x65xportLocalCoordinates\x18\x02 \x01(\x08\x12\x1b\n\x13undefinedValueLabel\x18\x03 \x01(\t\x12\x1e\n\x16\x65xcludeUndefinedValues\x18\x04 \x01(\x08\x12\x0e\n\x06viewId\x18\x05 \x01(\x05\"&\n\x12SaveProjectRequest\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\"\xb1\x12\n\rCommandParams\x12,\n\x0bopenProject\x18\x01 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12#\n\x0c\x63loseProject\x18\x02 \x01(\x0b\x32\x0b.rips.EmptyH\x00\x12,\n\x0bsetStartDir\x18\x03 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12)\n\x08loadCase\x18\x04 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12/\n\x0breplaceCase\x18\x05 \x01(\x0b\x32\x18.rips.ReplaceCaseRequestH\x00\x12=\n\x12replaceSourceCases\x18\x06 \x01(\x0b\x32\x1f.rips.ReplaceSourceCasesRequestH\x00\x12@\n\x18\x65xportMultiCaseSnapshots\x18\x07 \x01(\x0b\x32\x1c.rips.ExportMultiCaseRequestH\x00\x12\x37\n\x0f\x65xportSnapshots\x18\x08 \x01(\x0b\x32\x1c.rips.ExportSnapshotsRequestH\x00\x12\x35\n\x0e\x65xportProperty\x18\t \x01(\x0b\x32\x1b.rips.ExportPropertyRequestH\x00\x12\x43\n\x15\x65xportPropertyInViews\x18\n \x01(\x0b\x32\".rips.ExportPropertyInViewsRequestH\x00\x12\x44\n\x19\x65xportWellPathCompletions\x18\x0b \x01(\x0b\x32\x1f.rips.ExportWellPathCompRequestH\x00\x12N\n exportSimWellFractureCompletions\x18\x0c \x01(\x0b\x32\".rips.ExportSimWellPathFracRequestH\x00\x12+\n\texportMsw\x18\r \x01(\x0b\x32\x16.rips.ExportMswRequestH\x00\x12\x36\n\x0f\x65xportWellPaths\x18\x0e \x01(\x0b\x32\x1b.rips.ExportWellPathRequestH\x00\x12=\n\x12\x65xportVisibleCells\x18\x0f \x01(\x0b\x32\x1f.rips.ExportVisibleCellsRequestH\x00\x12\x37\n\x0fsetExportFolder\x18\x10 \x01(\x0b\x32\x1c.rips.SetExportFolderRequestH\x00\x12\x37\n\x0frunOctaveScript\x18\x11 \x01(\x0b\x32\x1c.rips.RunOctaveScriptRequestH\x00\x12\x36\n\x11setMainWindowSize\x18\x12 \x01(\x0b\x32\x19.rips.SetWindowSizeParamsH\x00\x12G\n\x1a\x63omputeCaseGroupStatistics\x18\x13 \x01(\x0b\x32!.rips.ComputeCaseGroupStatRequestH\x00\x12.\n\x0bsetTimeStep\x18\x14 \x01(\x0b\x32\x17.rips.SetTimeStepParamsH\x00\x12\x43\n\x15scaleFractureTemplate\x18\x15 \x01(\x0b\x32\".rips.ScaleFractureTemplateRequestH\x00\x12\x41\n\x16setFractureContainment\x18\x16 \x01(\x0b\x32\x1f.rips.SetFracContainmentRequestH\x00\x12\x42\n\x17\x63reateMultipleFractures\x18\x17 \x01(\x0b\x32\x1f.rips.CreateMultipleFracRequestH\x00\x12@\n\x17\x63reateLgrForCompletions\x18\x18 \x01(\x0b\x32\x1d.rips.CreateLgrForCompRequestH\x00\x12H\n\x1d\x63reateSaturationPressurePlots\x18\x19 \x01(\x0b\x32\x1f.rips.CreateSatPressPlotRequestH\x00\x12\x39\n\x14replaceMultipleCases\x18\x1a \x01(\x0b\x32\x19.rips.ReplaceCaseRequestsH\x00\x12?\n\x13\x63reateGridCaseGroup\x18\x1b \x01(\x0b\x32 .rips.CreateGridCaseGroupRequestH\x00\x12\x41\n\x14\x63reateStatisticsCase\x18\x1c \x01(\x0b\x32!.rips.CreateStatisticsCaseRequestH\x00\x12@\n\x19\x65xportFlowCharacteristics\x18\x1d \x01(\x0b\x32\x1b.rips.ExportFlowInfoRequestH\x00\x12-\n\ncreateView\x18\x1e \x01(\x0b\x32\x17.rips.CreateViewRequestH\x00\x12+\n\tcloneView\x18\x1f \x01(\x0b\x32\x16.rips.CloneViewRequestH\x00\x12\x41\n\x1b\x63reateWellBoreStabilityPlot\x18  \x01(\x0b\x32\x1a.rips.CreateWbsPlotRequestH\x00\x12\x37\n\x0fimportWellPaths\x18! \x01(\x0b\x32\x1c.rips.ImportWellPathsRequestH\x00\x12=\n\x12importWellLogFiles\x18\" \x01(\x0b\x32\x1f.rips.ImportWellLogFilesRequestH\x00\x12\x41\n\x14importFormationNames\x18# \x01(\x0b\x32!.rips.ImportFormationNamesRequestH\x00\x12\x43\n\x15\x65xportWellLogPlotData\x18$ \x01(\x0b\x32\".rips.ExportWellLogPlotDataRequestH\x00\x12\x36\n\x11setPlotWindowSize\x18% \x01(\x0b\x32\x19.rips.SetWindowSizeParamsH\x00\x12\x45\n\x16\x65xportContourMapToText\x18& \x01(\x0b\x32#.rips.ExportContourMapToTextRequestH\x00\x12/\n\x0bsaveProject\x18\' \x01(\x0b\x32\x18.rips.SaveProjectRequestH\x00\x42\x08\n\x06params\"9\n\x13GridCaseGroupResult\x12\x0f\n\x07groupId\x18\x01 \x01(\x05\x12\x11\n\tgroupName\x18\x02 \x01(\t\",\n\x1a\x43reateStatisticsCaseResult\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\"\"\n\x10\x43reateViewResult\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\"%\n\x13\x43reateWbsPlotResult\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\".\n\x15ImportWellPathsResult\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\"1\n\x18ImportWellLogFilesResult\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\"4\n\x1b\x45xportWellLogPlotDataResult\x12\x15\n\rexportedFiles\x18\x01 \x03(\t\"\xab\x04\n\x0c\x43ommandReply\x12\"\n\x0b\x65mptyResult\x18\x01 \x01(\x0b\x32\x0b.rips.EmptyH\x00\x12+\n\x0eloadCaseResult\x18\x02 \x01(\x0b\x32\x11.rips.CaseRequestH\x00\x12>\n\x19\x63reateGridCaseGroupResult\x18\x03 \x01(\x0b\x32\x19.rips.GridCaseGroupResultH\x00\x12\x46\n\x1a\x63reateStatisticsCaseResult\x18\x04 \x01(\x0b\x32 .rips.CreateStatisticsCaseResultH\x00\x12\x32\n\x10\x63reateViewResult\x18\x05 \x01(\x0b\x32\x16.rips.CreateViewResultH\x00\x12\x38\n\x13\x63reateWbsPlotResult\x18\x06 \x01(\x0b\x32\x19.rips.CreateWbsPlotResultH\x00\x12<\n\x15importWellPathsResult\x18\x07 \x01(\x0b\x32\x1b.rips.ImportWellPathsResultH\x00\x12\x42\n\x18importWellLogFilesResult\x18\x08 \x01(\x0b\x32\x1e.rips.ImportWellLogFilesResultH\x00\x12H\n\x1b\x65xportWellLogPlotDataResult\x18\t \x01(\x0b\x32!.rips.ExportWellLogPlotDataResultH\x00\x42\x08\n\x06result*$\n\x10PlotOutputFormat\x12\x07\n\x03PNG\x10\x00\x12\x07\n\x03PDF\x10\x01*-\n\x0cSnapshotType\x12\t\n\x05VIEWS\x10\x00\x12\t\n\x05PLOTS\x10\x01\x12\x07\n\x03\x41LL\x10\x02*`\n\x12\x43ompdatExportSplit\x12\x10\n\x0cUNIFIED_FILE\x10\x00\x12\x11\n\rSPLIT_ON_WELL\x10\x01\x12%\n!SPLIT_ON_WELL_AND_COMPLETION_TYPE\x10\x02*k\n\x11\x43ompdatExportType\x12\x16\n\x12TRANSMISSIBILITIES\x10\x00\x12*\n&WPIMULT_AND_DEFAULT_CONNECTION_FACTORS\x10\x01\x12\x12\n\x0eNO_COMPLETIONS\x10\x02*8\n\x16\x43ompdatCombinationMode\x12\x10\n\x0cINDIVIDUALLY\x10\x00\x12\x0c\n\x08\x43OMBINED\x10\x01*v\n\x10\x45xportFolderType\x12\x0f\n\x0b\x43OMPLETIONS\x10\x00\x12\r\n\tSNAPSHOTS\x10\x01\x12\x0e\n\nPROPERTIES\x10\x02\x12\x0e\n\nSTATISTICS\x10\x03\x12\r\n\tWELLPATHS\x10\x04\x12\t\n\x05\x43\x45LLS\x10\x05\x12\x08\n\x04LGRS\x10\x06*K\n\x12MultipleFracAction\x12\x08\n\x04NONE\x10\x00\x12\x14\n\x10\x41PPEND_FRACTURES\x10\x01\x12\x15\n\x11REPLACE_FRACTURES\x10\x02*J\n\x0cLgrSplitType\x12\x10\n\x0cLGR_PER_CELL\x10\x00\x12\x16\n\x12LGR_PER_COMPLETION\x10\x01\x12\x10\n\x0cLGR_PER_WELL\x10\x02*\"\n\x0c\x45xportFormat\x12\x07\n\x03LAS\x10\x00\x12\t\n\x05\x41SCII\x10\x01\x32@\n\x08\x43ommands\x12\x34\n\x07\x45xecute\x12\x13.rips.CommandParams\x1a\x12.rips.CommandReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Commands_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLOTOUTPUTFORMAT']._serialized_start=7055
  _globals['_PLOTOUTPUTFORMAT']._serialized_end=7091
  _globals['_SNAPSHOTTYPE']._serialized_start=7093
  _globals['_SNAPSHOTTYPE']._serialized_end=7138
  _globals['_COMPDATEXPORTSPLIT']._serialized_start=7140
  _globals['_COMPDATEXPORTSPLIT']._serialized_end=7236
  _globals['_COMPDATEXPORTTYPE']._serialized_start=7238
  _globals['_COMPDATEXPORTTYPE']._serialized_end=7345
  _globals['_COMPDATCOMBINATIONMODE']._serialized_start=7347
  _globals['_COMPDATCOMBINATIONMODE']._serialized_end=7403
  _globals['_EXPORTFOLDERTYPE']._serialized_start=7405
  _globals['_EXPORTFOLDERTYPE']._serialized_end=7523
  _globals['_MULTIPLEFRACACTION']._serialized_start=7525
  _globals['_MULTIPLEFRACACTION']._serialized_end=7600
  _globals['_LGRSPLITTYPE']._serialized_start=7602
  _globals['_LGRSPLITTYPE']._serialized_end=7676
  _globals['_EXPORTFORMAT']._serialized_start=7678
  _globals['_EXPORTFORMAT']._serialized_end=7712
  _globals['_FILEPATHREQUEST']._serialized_start=72
  _globals['_FILEPATHREQUEST']._serialized_end=121
  _globals['_REPLACECASEREQUEST']._serialized_start=123
  _globals['_REPLACECASEREQUEST']._serialized_end=180
  _globals['_REPLACECASEREQUESTS']._serialized_start=182
  _globals['_REPLACECASEREQUESTS']._serialized_end=248
  _globals['_REPLACESOURCECASESREQUEST']._serialized_start=250
  _globals['_REPLACESOURCECASESREQUEST']._serialized_end=320
  _globals['_EXPORTMULTICASEREQUEST']._serialized_start=322
  _globals['_EXPORTMULTICASEREQUEST']._serialized_end=368
  _globals['_EXPORTSNAPSHOTSREQUEST']._serialized_start=371
  _globals['_EXPORTSNAPSHOTSREQUEST']._serialized_end=549
  _globals['_EXPORTPROPERTYREQUEST']._serialized_start=552
  _globals['_EXPORTPROPERTYREQUEST']._serialized_end=695
  _globals['_EXPORTPROPERTYINVIEWSREQUEST']._serialized_start=697
  _globals['_EXPORTPROPERTYINVIEWSREQUEST']._serialized_end=784
  _globals['_EXPORTWELLPATHCOMPREQUEST']._serialized_start=787
  _globals['_EXPORTWELLPATHCOMPREQUEST']._serialized_end=1182
  _globals['_EXPORTSIMWELLPATHFRACREQUEST']._serialized_start=1185
  _globals['_EXPORTSIMWELLPATHFRACREQUEST']._serialized_end=1387
  _globals['_EXPORTMSWREQUEST']._serialized_start=1389
  _globals['_EXPORTMSWREQUEST']._serialized_end=1441
  _globals['_EXPORTWELLPATHREQUEST']._serialized_start=1443
  _globals['_EXPORTWELLPATHREQUEST']._serialized_end=1509
  _globals['_EXPORTVISIBLECELLSREQUEST']._serialized_start=1512
  _globals['_EXPORTVISIBLECELLSREQUEST']._serialized_end=1687
  _globals['_SETEXPORTFOLDERREQUEST']._serialized_start=1689
  _globals['_SETEXPORTFOLDERREQUEST']._serialized_end=1787
  _globals['_RUNOCTAVESCRIPTREQUEST']._serialized_start=1789
  _globals['_RUNOCTAVESCRIPTREQUEST']._serialized_end=1844
  _globals['_SETWINDOWSIZEPARAMS']._serialized_start=1846
  _globals['_SETWINDOWSIZEPARAMS']._serialized_end=1898
  _globals['_COMPUTECASEGROUPSTATREQUEST']._serialized_start=1900
  _globals['_COMPUTECASEGROUPSTATREQUEST']._serialized_end=1967
  _globals['_SETTIMESTEPPARAMS']._serialized_start=1969
  _globals['_SETTIMESTEPPARAMS']._serialized_end=2038
  _globals['_SCALEFRACTURETEMPLATEREQUEST']._serialized_start=2040
  _globals['_SCALEFRACTURETEMPLATEREQUEST']._serialized_end=2118
  _globals['_SETFRACCONTAINMENTREQUEST']._serialized_start=2120
  _globals['_SETFRACCONTAINMENTREQUEST']._serialized_end=2196
  _globals['_CREATEMULTIPLEFRACREQUEST']._serialized_start=2199
  _globals['_CREATEMULTIPLEFRACREQUEST']._serialized_end=2437
  _globals['_CREATELGRFORCOMPREQUEST']._serialized_start=2440
  _globals['_CREATELGRFORCOMPREQUEST']._serialized_end=2624
  _globals['_CREATESATPRESSPLOTREQUEST']._serialized_start=2626
  _globals['_CREATESATPRESSPLOTREQUEST']._serialized_end=2670
  _globals['_CREATEGRIDCASEGROUPREQUEST']._serialized_start=2672
  _globals['_CREATEGRIDCASEGROUPREQUEST']._serialized_end=2719
  _globals['_CREATESTATISTICSCASEREQUEST']._serialized_start=2721
  _globals['_CREATESTATISTICSCASEREQUEST']._serialized_end=2771
  _globals['_EXPORTFLOWINFOREQUEST']._serialized_start=2774
  _globals['_EXPORTFLOWINFOREQUEST']._serialized_end=2948
  _globals['_CREATEVIEWREQUEST']._serialized_start=2950
  _globals['_CREATEVIEWREQUEST']._serialized_end=2985
  _globals['_CLONEVIEWREQUEST']._serialized_start=2987
  _globals['_CLONEVIEWREQUEST']._serialized_end=3021
  _globals['_CREATEWBSPLOTREQUEST']._serialized_start=3023
  _globals['_CREATEWBSPLOTREQUEST']._serialized_end=3137
  _globals['_IMPORTWELLPATHSREQUEST']._serialized_start=3139
  _globals['_IMPORTWELLPATHSREQUEST']._serialized_end=3210
  _globals['_IMPORTWELLLOGFILESREQUEST']._serialized_start=3212
  _globals['_IMPORTWELLLOGFILESREQUEST']._serialized_end=3284
  _globals['_IMPORTFORMATIONNAMESREQUEST']._serialized_start=3286
  _globals['_IMPORTFORMATIONNAMESREQUEST']._serialized_end=3362
  _globals['_EXPORTWELLLOGPLOTDATAREQUEST']._serialized_start=3365
  _globals['_EXPORTWELLLOGPLOTDATAREQUEST']._serialized_end=3599
  _globals['_EXPORTCONTOURMAPTOTEXTREQUEST']._serialized_start=3602
  _globals['_EXPORTCONTOURMAPTOTEXTREQUEST']._serialized_end=3766
  _globals['_SAVEPROJECTREQUEST']._serialized_start=3768
  _globals['_SAVEPROJECTREQUEST']._serialized_end=3806
  _globals['_COMMANDPARAMS']._serialized_start=3809
  _globals['_COMMANDPARAMS']._serialized_end=6162
  _globals['_GRIDCASEGROUPRESULT']._serialized_start=6164
  _globals['_GRIDCASEGROUPRESULT']._serialized_end=6221
  _globals['_CREATESTATISTICSCASERESULT']._serialized_start=6223
  _globals['_CREATESTATISTICSCASERESULT']._serialized_end=6267
  _globals['_CREATEVIEWRESULT']._serialized_start=6269
  _globals['_CREATEVIEWRESULT']._serialized_end=6303
  _globals['_CREATEWBSPLOTRESULT']._serialized_start=6305
  _globals['_CREATEWBSPLOTRESULT']._serialized_end=6342
  _globals['_IMPORTWELLPATHSRESULT']._serialized_start=6344
  _globals['_IMPORTWELLPATHSRESULT']._serialized_end=6390
  _globals['_IMPORTWELLLOGFILESRESULT']._serialized_start=6392
  _globals['_IMPORTWELLLOGFILESRESULT']._serialized_end=6441
  _globals['_EXPORTWELLLOGPLOTDATARESULT']._serialized_start=6443
  _globals['_EXPORTWELLLOGPLOTDATARESULT']._serialized_end=6495
  _globals['_COMMANDREPLY']._serialized_start=6498
  _globals['_COMMANDREPLY']._serialized_end=7053
  _globals['_COMMANDS']._serialized_start=7714
  _globals['_COMMANDS']._serialized_end=7778
# @@protoc_insertion_point(module_scope)



###################################################################################
# This example will connect to ResInsight, retrieve a list of wells and print info
#
###################################################################################

# Import the ResInsight Processing Server Module
import rips

# Connect to ResInsight
resinsight = rips.Instance.find()
if resinsight is not None:
    # Get a list of all wells
    wells = resinsight.project.well_paths()

    print("Got " + str(len(wells)) + " wells: ")
    for well in wells:
        print("Well name: " + well.name)



######################################################################
# This script applies a cell result to the first view in the project
######################################################################
import rips

resinsight = rips.Instance.find()

view = resinsight.project.views()[0]
view.apply_cell_result(result_type="STATIC_NATIVE", result_variable="DX")



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import Case_pb2 as Case__pb2
import Definitions_pb2 as Definitions__pb2
import NNCProperties_pb2 as NNCProperties__pb2


class NNCPropertiesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAvailableNNCProperties = channel.unary_unary(
                '/rips.NNCProperties/GetAvailableNNCProperties',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=NNCProperties__pb2.AvailableNNCProperties.FromString,
                )
        self.GetNNCConnections = channel.unary_stream(
                '/rips.NNCProperties/GetNNCConnections',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=NNCProperties__pb2.NNCConnections.FromString,
                )
        self.GetNNCValues = channel.unary_stream(
                '/rips.NNCProperties/GetNNCValues',
                request_serializer=NNCProperties__pb2.NNCValuesRequest.SerializeToString,
                response_deserializer=NNCProperties__pb2.NNCValues.FromString,
                )
        self.SetNNCValues = channel.stream_unary(
                '/rips.NNCProperties/SetNNCValues',
                request_serializer=NNCProperties__pb2.NNCValuesChunk.SerializeToString,
                response_deserializer=Definitions__pb2.ClientToServerStreamReply.FromString,
                )


class NNCPropertiesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAvailableNNCProperties(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNNCConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNNCValues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNNCValues(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NNCPropertiesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAvailableNNCProperties': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableNNCProperties,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=NNCProperties__pb2.AvailableNNCProperties.SerializeToString,
            ),
            'GetNNCConnections': grpc.unary_stream_rpc_method_handler(
                    servicer.GetNNCConnections,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=NNCProperties__pb2.NNCConnections.SerializeToString,
            ),
            'GetNNCValues': grpc.unary_stream_rpc_method_handler(
                    servicer.GetNNCValues,
                    request_deserializer=NNCProperties__pb2.NNCValuesRequest.FromString,
                    response_serializer=NNCProperties__pb2.NNCValues.SerializeToString,
            ),
            'SetNNCValues': grpc.stream_unary_rpc_method_handler(
                    servicer.SetNNCValues,
                    request_deserializer=NNCProperties__pb2.NNCValuesChunk.FromString,
                    response_serializer=Definitions__pb2.ClientToServerStreamReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'rips.NNCProperties', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NNCProperties(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAvailableNNCProperties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.NNCProperties/GetAvailableNNCProperties',
            Case__pb2.CaseRequest.SerializeToString,
            NNCProperties__pb2.AvailableNNCProperties.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNNCConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.NNCProperties/GetNNCConnections',
            Case__pb2.CaseRequest.SerializeToString,
            NNCProperties__pb2.NNCConnections.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNNCValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.NNCProperties/GetNNCValues',
            NNCProperties__pb2.NNCValuesRequest.SerializeToString,
            NNCProperties__pb2.NNCValues.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetNNCValues(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/rips.NNCProperties/SetNNCValues',
            NNCProperties__pb2.NNCValuesChunk.SerializeToString,
            Definitions__pb2.ClientToServerStreamReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: App.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2
import PdmObject_pb2 as PdmObject__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tApp.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\x1a\x0fPdmObject.proto\"N\n\x07Version\x12\x15\n\rmajor_version\x18\x01 \x01(\x05\x12\x15\n\rminor_version\x18\x02 \x01(\x05\x12\x15\n\rpatch_version\x18\x03 \x01(\x05\":\n\x0bRuntimeInfo\x12+\n\x08\x61pp_type\x18\x01 \x01(\x0e\x32\x19.rips.ApplicationTypeEnum*C\n\x13\x41pplicationTypeEnum\x12\x13\n\x0fGUI_APPLICATION\x10\x00\x12\x17\n\x13\x43ONSOLE_APPLICATION\x10\x01\x32\xb9\x01\n\x03\x41pp\x12*\n\nGetVersion\x12\x0b.rips.Empty\x1a\r.rips.Version\"\x00\x12\"\n\x04\x45xit\x12\x0b.rips.Empty\x1a\x0b.rips.Empty\"\x00\x12\x32\n\x0eGetRuntimeInfo\x12\x0b.rips.Empty\x1a\x11.rips.RuntimeInfo\"\x00\x12.\n\x0cGetPdmObject\x12\x0b.rips.Empty\x1a\x0f.rips.PdmObject\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'App_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_APPLICATIONTYPEENUM']._serialized_start=195
  _globals['_APPLICATIONTYPEENUM']._serialized_end=262
  _globals['_VERSION']._serialized_start=55
  _globals['_VERSION']._serialized_end=133
  _globals['_RUNTIMEINFO']._serialized_start=135
  _globals['_RUNTIMEINFO']._serialized_end=193
  _globals['_APP']._serialized_start=265
  _globals['_APP']._serialized_end=450
# @@protoc_insertion_point(module_scope)



import sys
import os
import tempfile
from pathlib import Path
import pytest

sys.path.insert(1, os.path.join(sys.path[0], "../../"))
import rips

import dataroot


@pytest.mark.skipif(
    sys.platform.startswith("linux"),
    reason="Brugge is currently exceptionally slow on Linux",
)
def test_create_and_export_surface(rips_instance, initialize_test):
    case_path = dataroot.PATH + "/Case_with_10_timesteps/Real0/BRUGGE_0000.EGRID"
    case = rips_instance.project.load_case(path=case_path)
    assert len(case.grids()) == 1

    surface_collection = rips_instance.project.descendants(rips.SurfaceCollection)[0]

    surface = surface_collection.new_surface(case, 5)
    assert surface

    with tempfile.TemporaryDirectory(prefix="rips") as tmpdirname:
        path = Path(tmpdirname, "mysurface.ts")
        print("Temporary folder: ", path.as_posix())

        fname = surface.export_to_file(path.as_posix())
        assert len(fname.values) == 1

        assert path.exists()



"""
ResInsight 3d contour map module
"""
import Commands_pb2

from .pdmobject import add_method
from .view import View
from .resinsight_classes import EclipseContourMap, GeoMechContourMap


@add_method(EclipseContourMap)
def export_to_text(
    self,
    export_file_name="",
    export_local_coordinates=False,
    undefined_value_label="NaN",
    exclude_undefined_values=False,
):
    """Export snapshot for the current view

    Arguments:
        export_file_name(str): The file location to store results in.
        export_local_coordinates(bool): Should we export local coordinates, or UTM.
        undefined_value_label(str): Replace undefined values with this label.
        exclude_undefined_values(bool): Skip undefined values.
    """
    return self._execute_command(
        exportContourMapToText=Commands_pb2.ExportContourMapToTextRequest(
            exportFileName=export_file_name,
            exportLocalCoordinates=export_local_coordinates,
            undefinedValueLabel=undefined_value_label,
            excludeUndefinedValues=exclude_undefined_values,
            viewId=self.id,
        )
    )


@add_method(GeoMechContourMap)
def export_to_text(
    self,
    export_file_name="",
    export_local_coordinates=False,
    undefined_value_label="NaN",
    exclude_undefined_values=False,
):
    """Export snapshot for the current view

    Arguments:
        export_file_name(str): The file location to store results in.
        export_local_coordinates(bool): Should we export local coordinates, or UTM.
        undefined_value_label(str): Replace undefined values with this label.
        exclude_undefined_values(bool): Skip undefined values.
    """
    return self._execute_command(
        exportContourMapToText=Commands_pb2.ExportContourMapToTextRequest(
            exportFileName=export_file_name,
            exportLocalCoordinates=export_local_coordinates,
            undefinedValueLabel=undefined_value_label,
            excludeUndefinedValues=exclude_undefined_values,
            viewId=self.id,
        )
    )



import sys
import os
import tempfile

sys.path.insert(1, os.path.join(sys.path[0], "../../"))
import rips

import dataroot


def test_10k(rips_instance, initialize_test):
    case_root_path = dataroot.PATH + "/TEST10K_FLT_LGR_NNC"
    project_path = case_root_path + "/well_completions_pytest.rsp"
    project = rips_instance.project.open(path=project_path)

    export_folder = tempfile.gettempdir()

    rips_instance.set_export_folder(export_type="COMPLETIONS", path=export_folder)

    case = project.cases()[0]
    case.export_well_path_completions(
        time_step=1,
        well_path_names=["Well-1"],
        file_split="UNIFIED_FILE",
    )



import pytest
import sys
import os
import getopt

sys.path.insert(1, os.path.join(sys.path[0], "../../"))
import rips

_rips_instance = None


@pytest.fixture
def rips_instance():
    return _rips_instance


@pytest.fixture
def initialize_test():
    _rips_instance.project.close()  # make sure ResInsight is clean before execution of test
    yield initialize_test
    _rips_instance.project.close()  # make sure ResInsight is clean after test


def pytest_addoption(parser):
    parser.addoption(
        "--console",
        action="store_true",
        default=False,
        help="Run as console application",
    )
    parser.addoption(
        "--existing",
        action="store_true",
        default=False,
        help="Look for existing ResInsight",
    )


def pytest_configure(config):
    global _rips_instance
    console = False
    if config.getoption("--existing"):
        print("Looking for existing ResInsight")
        _rips_instance = rips.Instance.find()
    else:
        if config.getoption("--console"):
            console = True
        _rips_instance = rips.Instance.launch(console=console)
    if not _rips_instance:
        print("Need a valid ResInsight executable to launch tests")
        exit(0)


def pytest_unconfigure(config):
    if not config.getoption("--existing"):
        if _rips_instance:
            _rips_instance.exit()



# Load ResInsight Processing Server Client Library
import rips

# Connect to ResInsight instance
resinsight = rips.Instance.find()
# Example code
project = resinsight.project

summary_cases = project.descendants(rips.SummaryCase)
summary_plot_collection = project.descendants(rips.SummaryPlotCollection)[0]
if len(summary_cases) > 0:
    summary_plot = summary_plot_collection.new_summary_plot(
        summary_cases=summary_cases, address="FOP*"
    )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import Case_pb2 as Case__pb2
import Definitions_pb2 as Definitions__pb2
import PdmObject_pb2 as PdmObject__pb2


class CaseStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetGridCount = channel.unary_unary(
                '/rips.Case/GetGridCount',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=Case__pb2.GridCount.FromString,
                )
        self.GetCellCount = channel.unary_unary(
                '/rips.Case/GetCellCount',
                request_serializer=Case__pb2.CellInfoRequest.SerializeToString,
                response_deserializer=Case__pb2.CellCount.FromString,
                )
        self.GetCellInfoForActiveCells = channel.unary_stream(
                '/rips.Case/GetCellInfoForActiveCells',
                request_serializer=Case__pb2.CellInfoRequest.SerializeToString,
                response_deserializer=Case__pb2.CellInfoArray.FromString,
                )
        self.GetCellCenterForActiveCells = channel.unary_stream(
                '/rips.Case/GetCellCenterForActiveCells',
                request_serializer=Case__pb2.CellInfoRequest.SerializeToString,
                response_deserializer=Definitions__pb2.CellCenters.FromString,
                )
        self.GetCellCornersForActiveCells = channel.unary_stream(
                '/rips.Case/GetCellCornersForActiveCells',
                request_serializer=Case__pb2.CellInfoRequest.SerializeToString,
                response_deserializer=Definitions__pb2.CellCornersArray.FromString,
                )
        self.GetCoarseningInfoArray = channel.unary_unary(
                '/rips.Case/GetCoarseningInfoArray',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=Case__pb2.CoarseningInfoArray.FromString,
                )
        self.GetTimeSteps = channel.unary_unary(
                '/rips.Case/GetTimeSteps',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=Case__pb2.TimeStepDates.FromString,
                )
        self.GetSelectedCells = channel.unary_stream(
                '/rips.Case/GetSelectedCells',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=Case__pb2.SelectedCells.FromString,
                )
        self.GetDaysSinceStart = channel.unary_unary(
                '/rips.Case/GetDaysSinceStart',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=Case__pb2.DaysSinceStart.FromString,
                )
        self.GetCaseInfo = channel.unary_unary(
                '/rips.Case/GetCaseInfo',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=Case__pb2.CaseInfo.FromString,
                )
        self.GetPdmObject = channel.unary_unary(
                '/rips.Case/GetPdmObject',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=PdmObject__pb2.PdmObject.FromString,
                )
        self.GetReservoirBoundingBox = channel.unary_unary(
                '/rips.Case/GetReservoirBoundingBox',
                request_serializer=Case__pb2.CaseRequest.SerializeToString,
                response_deserializer=Case__pb2.BoundingBox.FromString,
                )


class CaseServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetGridCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCellCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCellInfoForActiveCells(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCellCenterForActiveCells(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCellCornersForActiveCells(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCoarseningInfoArray(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTimeSteps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelectedCells(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDaysSinceStart(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCaseInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPdmObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReservoirBoundingBox(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CaseServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetGridCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGridCount,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=Case__pb2.GridCount.SerializeToString,
            ),
            'GetCellCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCellCount,
                    request_deserializer=Case__pb2.CellInfoRequest.FromString,
                    response_serializer=Case__pb2.CellCount.SerializeToString,
            ),
            'GetCellInfoForActiveCells': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCellInfoForActiveCells,
                    request_deserializer=Case__pb2.CellInfoRequest.FromString,
                    response_serializer=Case__pb2.CellInfoArray.SerializeToString,
            ),
            'GetCellCenterForActiveCells': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCellCenterForActiveCells,
                    request_deserializer=Case__pb2.CellInfoRequest.FromString,
                    response_serializer=Definitions__pb2.CellCenters.SerializeToString,
            ),
            'GetCellCornersForActiveCells': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCellCornersForActiveCells,
                    request_deserializer=Case__pb2.CellInfoRequest.FromString,
                    response_serializer=Definitions__pb2.CellCornersArray.SerializeToString,
            ),
            'GetCoarseningInfoArray': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCoarseningInfoArray,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=Case__pb2.CoarseningInfoArray.SerializeToString,
            ),
            'GetTimeSteps': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTimeSteps,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=Case__pb2.TimeStepDates.SerializeToString,
            ),
            'GetSelectedCells': grpc.unary_stream_rpc_method_handler(
                    servicer.GetSelectedCells,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=Case__pb2.SelectedCells.SerializeToString,
            ),
            'GetDaysSinceStart': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDaysSinceStart,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=Case__pb2.DaysSinceStart.SerializeToString,
            ),
            'GetCaseInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCaseInfo,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=Case__pb2.CaseInfo.SerializeToString,
            ),
            'GetPdmObject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPdmObject,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=PdmObject__pb2.PdmObject.SerializeToString,
            ),
            'GetReservoirBoundingBox': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReservoirBoundingBox,
                    request_deserializer=Case__pb2.CaseRequest.FromString,
                    response_serializer=Case__pb2.BoundingBox.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'rips.Case', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Case(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetGridCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Case/GetGridCount',
            Case__pb2.CaseRequest.SerializeToString,
            Case__pb2.GridCount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCellCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Case/GetCellCount',
            Case__pb2.CellInfoRequest.SerializeToString,
            Case__pb2.CellCount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCellInfoForActiveCells(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Case/GetCellInfoForActiveCells',
            Case__pb2.CellInfoRequest.SerializeToString,
            Case__pb2.CellInfoArray.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCellCenterForActiveCells(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Case/GetCellCenterForActiveCells',
            Case__pb2.CellInfoRequest.SerializeToString,
            Definitions__pb2.CellCenters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCellCornersForActiveCells(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Case/GetCellCornersForActiveCells',
            Case__pb2.CellInfoRequest.SerializeToString,
            Definitions__pb2.CellCornersArray.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCoarseningInfoArray(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Case/GetCoarseningInfoArray',
            Case__pb2.CaseRequest.SerializeToString,
            Case__pb2.CoarseningInfoArray.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTimeSteps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Case/GetTimeSteps',
            Case__pb2.CaseRequest.SerializeToString,
            Case__pb2.TimeStepDates.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSelectedCells(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Case/GetSelectedCells',
            Case__pb2.CaseRequest.SerializeToString,
            Case__pb2.SelectedCells.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDaysSinceStart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Case/GetDaysSinceStart',
            Case__pb2.CaseRequest.SerializeToString,
            Case__pb2.DaysSinceStart.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCaseInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Case/GetCaseInfo',
            Case__pb2.CaseRequest.SerializeToString,
            Case__pb2.CaseInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPdmObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Case/GetPdmObject',
            Case__pb2.CaseRequest.SerializeToString,
            PdmObject__pb2.PdmObject.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReservoirBoundingBox(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Case/GetReservoirBoundingBox',
            Case__pb2.CaseRequest.SerializeToString,
            Case__pb2.BoundingBox.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
